@@ -16,11 +16,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: downloader-view.c,v 1.51 2004/02/01 00:49:46 xan Exp $
+ *  $Id: downloader-view.c,v 1.60 2004/05/24 21:50:34 xan Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h" 
 #endif
 
 #include "downloader-view.h"
@@ -70,7 +70,6 @@ struct DownloaderViewPrivate
 typedef struct
 {
 	gboolean is_paused;
-	gboolean can_abort;
 	DownloaderViewPrivate *priv;
 } ControlsInfo;
 
@@ -205,6 +204,8 @@ downloader_view_new (void)
 {
 	return EPHY_DOWNLOADER_VIEW (g_object_new (EPHY_TYPE_DOWNLOADER_VIEW,
 			 			   "persist-position", TRUE,
+						   "default-width", 420,
+						   "default-height", 250,
 			 			   NULL));
 }
 
@@ -234,6 +235,50 @@ get_row_from_download (DownloaderView *dv, EphyDownload *download)
 	return  g_hash_table_lookup (dv->priv->downloads_hash, download);
 }
 
+static void
+update_buttons (DownloaderView *dv)
+{
+	GtkTreeSelection *selection;
+	GtkTreeModel *model;
+	GtkTreeIter iter;
+	GValue val = {0, };
+	EphyDownload *download;
+	EphyDownloadState state;
+	gboolean pause_enabled = FALSE;
+	gboolean abort_enabled = FALSE;
+	gboolean label_pause = TRUE;
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(dv->priv->treeview));
+
+	if (gtk_tree_selection_get_selected (selection, &model, &iter))
+	{
+		gtk_tree_model_get_value (model, &iter, COL_DOWNLOAD_OBJECT, &val);
+		download = g_value_get_object (&val);
+		g_value_unset (&val);
+
+		state = ephy_download_get_state (download);
+
+		switch (state)
+		{
+		case EPHY_DOWNLOAD_DOWNLOADING:
+			pause_enabled = TRUE;
+			abort_enabled = TRUE;
+			break;
+		case EPHY_DOWNLOAD_PAUSED:
+			pause_enabled = TRUE;
+			abort_enabled = TRUE;
+			label_pause = FALSE;
+			break;
+		default:
+			abort_enabled = TRUE;
+			break;
+		}
+	}
+	gtk_widget_set_sensitive (dv->priv->pause_button, pause_enabled);
+	gtk_widget_set_sensitive (dv->priv->abort_button, abort_enabled);
+	gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), label_pause ? _("_Pause") : _("_Resume"));
+}
+
 static void
 update_download_row (DownloaderView *dv, EphyDownload *download)
 {
@@ -315,6 +360,8 @@ update_download_row (DownloaderView *dv, EphyDownload *download)
 	g_free (cur_progress);
 	g_free (file);
 	g_free (remaining);
+
+	update_buttons (dv);
 }
 
 static void
@@ -389,6 +436,8 @@ downloader_view_add_download (DownloaderView *dv,
 	GtkTreeSelection *selection;
 	GtkTreePath *path;
 
+	g_object_ref (download);
+
 	gtk_list_store_append (GTK_LIST_STORE (dv->priv->model),
 			       &iter);
 	gtk_list_store_set (GTK_LIST_STORE (dv->priv->model),
@@ -416,6 +465,12 @@ downloader_view_add_download (DownloaderView *dv,
 	ephy_dialog_show (EPHY_DIALOG (dv));
 }
 
+static void
+selection_changed (GtkTreeSelection *selection, DownloaderView *dv)
+{
+	update_buttons (dv);
+}
+
 static void
 downloader_view_build_ui (DownloaderView *dv)
 {
@@ -423,9 +478,9 @@ downloader_view_build_ui (DownloaderView *dv)
 	GtkListStore *liststore;
 	GtkTreeViewColumn *column;
 	GtkCellRenderer *renderer;
-	GtkTreeSelection *selection;
 	GdkPixbuf *icon;
 	EphyDialog *d = EPHY_DIALOG (dv);
+	GtkTreeSelection *selection;
 
 	ephy_dialog_construct (d,
                                properties,
@@ -462,6 +517,7 @@ downloader_view_build_ui (DownloaderView *dv)
 						     NULL);
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview), 0);
         gtk_tree_view_column_set_reorderable (column, TRUE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_sort_column_id (column, COL_PERCENT);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -474,6 +530,7 @@ downloader_view_build_ui (DownloaderView *dv)
 					   COL_FILE);
         gtk_tree_view_column_set_expand (column, TRUE);
         gtk_tree_view_column_set_reorderable (column, TRUE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_sort_column_id (column, COL_FILE);
 
 	renderer = gtk_cell_renderer_text_new ();
@@ -486,11 +543,9 @@ downloader_view_build_ui (DownloaderView *dv)
 	column = gtk_tree_view_get_column (GTK_TREE_VIEW(priv->treeview),
 					   COL_REMAINING);
         gtk_tree_view_column_set_reorderable (column, TRUE);
+	gtk_tree_view_column_set_resizable (column, TRUE);
         gtk_tree_view_column_set_sort_column_id (column, COL_REMAINING);
 
-	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(priv->treeview));
-	gtk_tree_selection_set_mode (selection, GTK_SELECTION_SINGLE);
-
 	priv->model = GTK_TREE_MODEL (liststore);
 
 	icon = gtk_widget_render_icon (GTK_WIDGET (priv->window),
@@ -498,6 +553,9 @@ downloader_view_build_ui (DownloaderView *dv)
 				       GTK_ICON_SIZE_MENU,
 				       NULL);
 	gtk_window_set_icon (GTK_WINDOW(priv->window), icon);
+
+	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (priv->treeview));
+	g_signal_connect (selection, "changed", G_CALLBACK (selection_changed), dv);
 }
 
 void
@@ -516,20 +574,21 @@ download_dialog_pause_cb (GtkButton *button, DownloaderView *dv)
 
 	gtk_tree_model_get_value (model, &iter, COL_DOWNLOAD_OBJECT, &val);
 	download = g_value_get_object (&val);
-	g_value_unset (&val);
 
 	state = ephy_download_get_state (download);
 
 	if (state == EPHY_DOWNLOAD_DOWNLOADING)
 	{
 		ephy_download_pause (download);
-		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("_Resume"));
 	}
 	else if (state == EPHY_DOWNLOAD_PAUSED)
 	{
 		ephy_download_resume (download);
-		gtk_button_set_label (GTK_BUTTON (dv->priv->pause_button), _("_Pause"));
 	}
+
+	g_value_unset (&val);
+
+	update_buttons (dv);
 }
 
 void
@@ -572,6 +631,7 @@ downloader_view_remove_download (DownloaderView *dv, EphyDownload *download)
 	gtk_list_store_remove (GTK_LIST_STORE (dv->priv->model), &iter2);
 	g_hash_table_remove (dv->priv->downloads_hash,
 			     download);
+	g_object_unref (download);
 
 	/* Actual selection */
 
@@ -606,15 +666,17 @@ download_dialog_abort_cb (GtkButton *button, DownloaderView *dv)
 
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW(dv->priv->treeview));
 	
-	gtk_tree_selection_get_selected (selection, &model, &iter);
+	if (!gtk_tree_selection_get_selected (selection, &model, &iter)) return;
+
 	gtk_tree_model_get_value (model, &iter, COL_DOWNLOAD_OBJECT, &val);
 	
 	download = g_value_get_object (&val);
-	g_value_unset (&val);
 	g_return_if_fail (download != NULL);
-	
+
 	ephy_download_cancel ((EphyDownload*)download);
 	downloader_view_remove_download (dv, download);
+
+	g_value_unset (&val);
 }
 
 gboolean
