@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.cpp,v 1.22 2004/03/05 11:48:17 chpe Exp $
+ *  $Id: EphyBrowser.cpp,v 1.37 2004/05/23 01:06:34 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -24,72 +24,67 @@
 
 #include "EphyBrowser.h"
 #include "GlobalHistory.h"
+#include "ContentHandler.h"
 #include "ephy-embed.h"
 #include "ephy-string.h"
+#include "ephy-debug.h"
 
 #include <gtkmozembed_internal.h>
 #include <unistd.h>
 
-#include "nsICommandManager.h"
+#include "nsIInterfaceRequestorUtils.h"
+#include "nsIURI.h"
+#include "nsISimpleEnumerator.h"
+
 #include "nsIContentViewer.h"
 #include "nsIGlobalHistory.h"
-#include "nsIDocShellHistory.h"
 #include "nsIWebBrowserFind.h"
 #include "nsIWebBrowserFocus.h"
-#include "nsIDocument.h"
-#include "nsISHEntry.h"
-#include "nsISHistoryInternal.h"
-#include "nsIHistoryEntry.h"
+#include "nsICommandManager.h"
 #include "nsIWebBrowserPrint.h"
-#include "nsIURI.h"
-#include "nsIMarkupDocumentViewer.h"
-#include "nsIComponentManager.h"
-#include "nsIScriptGlobalObject.h"
-#include "nsIDOMWindowInternal.h"
-#include "nsIInterfaceRequestor.h"
-#include "nsIFocusController.h"
-#include "nsIWebBrowserPersist.h"
-#include "nsCWebBrowserPersist.h"
-#include "nsNetUtil.h"
-#include "nsIChromeEventHandler.h"
-#include "nsIDOMDocument.h"
-#include "nsIDOMDocumentStyle.h"
-#include "nsIDOMEvent.h"
-#include "nsIDOMEventTarget.h"
-#include "nsIDOMNode.h"
-#include "nsIDOMElement.h"
-#include "nsIDOMPopupBlockedEvent.h"
 #include "nsIDocShellTreeItem.h"
 #include "nsIDocShellTreeNode.h"
 #include "nsIDocShellTreeOwner.h"
-#include "nsICSSLoader.h"
-#include "nsICSSStyleSheet.h"
-#include "nsICSSLoaderObserver.h"
-#include "nsIDocumentObserver.h"
-#include "nsCWebBrowser.h"
-#include "nsReadableUtils.h"
-#include "nsIDOMNSHTMLDocument.h"
+#include "nsIDocumentCharsetInfo.h"
+#include "nsIWebPageDescriptor.h"
+#include "nsISHEntry.h"
+#include "nsIHistoryEntry.h"
 #include "nsIDOMHTMLDocument.h"
 #include "nsIDOMHTMLCollection.h"
 #include "nsIDOMHTMLElement.h"
 #include "nsIDOMHTMLFormElement.h"
 #include "nsIDOMHTMLInputElement.h"
 #include "nsIDOMHTMLTextAreaElement.h"
+#include "nsIDOMDocument.h"
+#include "nsIDOMEvent.h"
+#include "nsIDOMEventTarget.h"
+#include "nsIDOMNode.h"
+#include "nsIDOMElement.h"
+
+#ifdef ALLOW_PRIVATE_API
+#include "nsPIDOMWindow.h"
+#include "nsIMarkupDocumentViewer.h"
+#include "nsIChromeEventHandler.h"
+#include "nsIDOMWindowInternal.h"
+#endif
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include "nsReadableUtils.h"
+#include "nsIDocument.h"
 #include "nsIDeviceContext.h"
 #include "nsIPresContext.h"
 #include "nsIAtom.h"
-#include "nsIDocumentCharsetInfo.h"
-#include "nsPromiseFlatString.h"
-#include "nsString.h"
-#include "ContentHandler.h"
+#endif
 
 EphyEventListener::EphyEventListener(void)
+: mOwner(nsnull)
 {
-	mOwner = nsnull;
+	LOG ("EphyEventListener ctor (%p)", this)
 }
 
 EphyEventListener::~EphyEventListener()
 {
+	LOG ("EphyEventListener dtor (%p)", this)
 }
 
 NS_IMPL_ISUPPORTS1(EphyEventListener, nsIDOMEventListener)
@@ -136,13 +131,10 @@ EphyFaviconEventListener::HandleFaviconLink (nsIDOMNode *node)
 #elif MOZILLA_SNAPSHOT > 11
 		nsIURI *uri;
 		uri = doc->GetDocumentURL ();
-#else
-		nsCOMPtr<nsIURI> uri;
-		doc->GetDocumentURL(getter_AddRefs(uri));
 #endif
 		if (!uri) return NS_ERROR_FAILURE;
 
-		const nsACString &link = NS_ConvertUCS2toUTF8(value);
+		const nsACString &link = NS_ConvertUTF16toUTF8(value);
 		nsCAutoString favicon_url;
 		result = uri->Resolve (link, favicon_url);
 		if (NS_FAILED (result)) return NS_ERROR_FAILURE;
@@ -170,25 +162,10 @@ EphyFaviconEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
 	return NS_OK;
 }
 
-NS_IMETHODIMP
-EphyPopupEventListener::HandleEvent(nsIDOMEvent* aDOMEvent)
-{
-	nsCOMPtr<nsIDOMPopupBlockedEvent> popupEvent =
-		do_QueryInterface(aDOMEvent);
-	if (popupEvent)
-	{
-		g_signal_emit_by_name (mOwner, "ge_popup_blocked");
-	}
-
-	return NS_OK;
-}
-
 EphyBrowser::EphyBrowser ()
+: mFaviconEventListener(nsnull)
+, mInitialized(PR_FALSE)
 {
-	mFaviconEventListener = nsnull;
-	mPopupEventListener = nsnull;
-	mEventReceiver = nsnull;
-	mInitialized = PR_FALSE;
 }
 
 EphyBrowser::~EphyBrowser ()
@@ -216,15 +193,9 @@ nsresult EphyBrowser::Init (GtkMozEmbed *mozembed)
 	mFaviconEventListener = new EphyFaviconEventListener();
 	if (!mFaviconEventListener) return NS_ERROR_OUT_OF_MEMORY;
 
-	mPopupEventListener = new EphyPopupEventListener();
-	if (!mPopupEventListener) return NS_ERROR_OUT_OF_MEMORY;
-
 	rv = mFaviconEventListener->Init (EPHY_EMBED (mozembed));
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	rv = mPopupEventListener->Init (EPHY_EMBED (mozembed));
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
  	rv = GetListener();
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -247,8 +218,13 @@ EphyBrowser::GetListener (void)
 	nsCOMPtr<nsPIDOMWindow> piWin(do_QueryInterface(domWindow));
 	NS_ENSURE_TRUE (piWin, NS_ERROR_FAILURE);
 
+#if MOZILLA_SNAPSHOT >= 18
+  	nsIChromeEventHandler* chromeHandler;
+  	chromeHandler = piWin->GetChromeEventHandler();
+#else
   	nsCOMPtr<nsIChromeEventHandler> chromeHandler;
   	piWin->GetChromeEventHandler(getter_AddRefs(chromeHandler));
+#endif
 
   	mEventReceiver = do_QueryInterface(chromeHandler);
 	NS_ENSURE_TRUE (mEventReceiver, NS_ERROR_FAILURE);
@@ -270,10 +246,6 @@ EphyBrowser::AttachListeners(void)
 				      mFaviconEventListener, PR_FALSE);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	rv = target->AddEventListener(NS_LITERAL_STRING("DOMPopupBlocked"),
-				      mPopupEventListener, PR_FALSE);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
 	return NS_OK;
 }
 
@@ -282,19 +254,16 @@ EphyBrowser::DetachListeners(void)
 {
 	nsresult rv;
 
-	NS_ENSURE_TRUE (mEventReceiver, NS_ERROR_FAILURE);
-	
+	if (!mEventReceiver) return NS_OK;
+
 	nsCOMPtr<nsIDOMEventTarget> target;
 	target = do_QueryInterface (mEventReceiver);
+	NS_ENSURE_TRUE (target, NS_ERROR_FAILURE);
 
 	rv = target->RemoveEventListener(NS_LITERAL_STRING("DOMLinkAdded"),
 					 mFaviconEventListener, PR_FALSE);
 	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
-	rv = target->RemoveEventListener(NS_LITERAL_STRING("DOMPopupBlocked"),
-					 mPopupEventListener, PR_FALSE);
-	NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
-
 	return NS_OK;
 }
 
@@ -394,14 +363,16 @@ nsresult EphyBrowser::Destroy ()
 	DetachListeners ();
 
       	mWebBrowser = nsnull;
-	
+	mDOMWindow = nsnull;
+	mEventReceiver = nsnull;
+
+	mInitialized = PR_FALSE;
+
 	return NS_OK;
 }
 
 nsresult EphyBrowser::GoToHistoryIndex (PRInt16 index)
 {
-	nsresult result;
-
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIWebNavigation> ContentNav = do_QueryInterface (mWebBrowser);
@@ -486,6 +457,8 @@ nsresult EphyBrowser::GetContentViewer (nsIContentViewer **aViewer)
 
 nsresult EphyBrowser::GetZoom (float *aZoom)
 {
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsIContentViewer> contentViewer;	
 	GetContentViewer (getter_AddRefs(contentViewer));
 	NS_ENSURE_TRUE (contentViewer, NS_ERROR_FAILURE);
@@ -535,6 +508,8 @@ nsresult EphyBrowser::GetTargetDocument (nsIDOMDocument **aDOMDocument)
 
 nsresult EphyBrowser::GetSHInfo (PRInt32 *count, PRInt32 *index)
 {
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsISHistory> SessionHistory;
 	GetSHistory (getter_AddRefs(SessionHistory));
 	NS_ENSURE_TRUE (SessionHistory, NS_ERROR_FAILURE);
@@ -547,6 +522,8 @@ nsresult EphyBrowser::GetSHInfo (PRInt32 *count, PRInt32 *index)
 
 nsresult EphyBrowser::GetSHTitleAtIndex (PRInt32 index, PRUnichar **title)
 {
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsISHistory> SessionHistory;
 	GetSHistory (getter_AddRefs(SessionHistory));
 	NS_ENSURE_TRUE (SessionHistory, NS_ERROR_FAILURE);
@@ -565,6 +542,8 @@ nsresult EphyBrowser::GetSHTitleAtIndex (PRInt32 index, PRUnichar **title)
 
 nsresult EphyBrowser::GetSHUrlAtIndex (PRInt32 index, nsCString &url)
 {
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsISHistory> SessionHistory;
 	GetSHistory (getter_AddRefs(SessionHistory));
 	NS_ENSURE_TRUE (SessionHistory, NS_ERROR_FAILURE);
@@ -616,8 +595,6 @@ nsresult EphyBrowser::Find (PRBool backwards,
 
 nsresult EphyBrowser::GetPageDescriptor(nsISupports **aPageDescriptor)
 {
-	nsresult rv;
-
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
 	nsCOMPtr<nsIDocShell> ds = do_GetInterface (mWebBrowser);
@@ -633,6 +610,8 @@ nsresult EphyBrowser::GetPageDescriptor(nsISupports **aPageDescriptor)
 
 nsresult EphyBrowser::GetDocumentUrl (nsCString &url)
 {
+	NS_ENSURE_TRUE (mDOMWindow, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsIDOMDocument> DOMDocument;
 	mDOMWindow->GetDocument (getter_AddRefs(DOMDocument));
 	NS_ENSURE_TRUE (DOMDocument, NS_ERROR_FAILURE);
@@ -646,9 +625,6 @@ nsresult EphyBrowser::GetDocumentUrl (nsCString &url)
 #elif MOZILLA_SNAPSHOT > 11
 	nsIURI *uri;
 	uri = doc->GetDocumentURL ();
-#else
-	nsCOMPtr<nsIURI> uri;
-	doc->GetDocumentURL(getter_AddRefs(uri));
 #endif
 	NS_ENSURE_TRUE (uri, NS_ERROR_FAILURE);
 
@@ -657,6 +633,8 @@ nsresult EphyBrowser::GetDocumentUrl (nsCString &url)
 
 nsresult EphyBrowser::GetTargetDocumentUrl (nsCString &url)
 {
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
         nsCOMPtr<nsIDOMDocument> DOMDocument;
 	GetTargetDocument (getter_AddRefs(DOMDocument));
 	NS_ENSURE_TRUE (DOMDocument, NS_ERROR_FAILURE);
@@ -670,9 +648,6 @@ nsresult EphyBrowser::GetTargetDocumentUrl (nsCString &url)
 #elif MOZILLA_SNAPSHOT > 11
 	nsIURI *uri;
 	uri = doc->GetDocumentURL ();
-#else
-        nsCOMPtr<nsIURI> uri;
-        doc->GetDocumentURL(getter_AddRefs(uri));
 #endif
 	NS_ENSURE_TRUE (uri, NS_ERROR_FAILURE);
 
@@ -681,6 +656,8 @@ nsresult EphyBrowser::GetTargetDocumentUrl (nsCString &url)
 
 nsresult EphyBrowser::ForceEncoding (const char *encoding) 
 {
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsIContentViewer> contentViewer;	
 	GetContentViewer (getter_AddRefs(contentViewer));
 	NS_ENSURE_TRUE (contentViewer, NS_ERROR_FAILURE);
@@ -688,14 +665,41 @@ nsresult EphyBrowser::ForceEncoding (const char *encoding)
 	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(contentViewer);
 	NS_ENSURE_TRUE (mdv, NS_ERROR_FAILURE);
 
-	nsresult result;
-#if MOZILLA_SNAPSHOT > 9 
-	result = mdv->SetForceCharacterSet (nsDependentCString(encoding));
-#else
-	result = mdv->SetForceCharacterSet (NS_ConvertUTF8toUCS2(encoding).get());
-#endif
+	return mdv->SetForceCharacterSet (nsDependentCString(encoding));
+}
 
-	return result;
+nsresult EphyBrowser::GetEncoding (nsACString &encoding)
+{
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDOMDocument> domDoc;
+	GetTargetDocument (getter_AddRefs(domDoc));
+	NS_ENSURE_TRUE (domDoc, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIDocument> doc = do_QueryInterface(domDoc);
+	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
+
+	encoding = doc->GetDocumentCharacterSet ();
+	NS_ENSURE_TRUE (!encoding.IsEmpty(), NS_ERROR_FAILURE);
+
+	return NS_OK;
+}
+
+nsresult EphyBrowser::GetForcedEncoding (nsACString &encoding)
+{
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIContentViewer> contentViewer;	
+	GetContentViewer (getter_AddRefs(contentViewer));
+	NS_ENSURE_TRUE (contentViewer, NS_ERROR_FAILURE);
+
+	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(contentViewer);
+	NS_ENSURE_TRUE (mdv, NS_ERROR_FAILURE);
+
+	nsresult result = mdv->GetForceCharacterSet (encoding);
+	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
+
+	return NS_OK;
 }
 
 nsresult EphyBrowser::PushTargetDocument (nsIDOMDocument *domDoc)
@@ -712,136 +716,11 @@ nsresult EphyBrowser::PopTargetDocument ()
 	return NS_OK;
 }
 
-nsresult EphyBrowser::GetEncodingInfo (EphyEncodingInfo **infoptr)
-{
-	nsresult result;
-	EphyEncodingInfo *info;
-
-	nsCOMPtr<nsIDOMDocument> domDoc;
-	GetTargetDocument (getter_AddRefs(domDoc));
-	NS_ENSURE_TRUE (domDoc, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDocument> doc = do_QueryInterface(domDoc, &result);
-	NS_ENSURE_TRUE (doc, NS_ERROR_FAILURE);
-
-	info = g_new0 (EphyEncodingInfo, 1);
-	*infoptr = info;
-
-	PRInt32 source;
-#if MOZILLA_SNAPSHOT > 11
-	source = doc->GetDocumentCharacterSetSource ();
-#else
-	result = doc->GetDocumentCharacterSetSource (&source);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
-#endif
-	info->encoding_source = (EphyEncodingSource) source;
-
-	nsCOMPtr<nsIDocShell> ds;
-	ds = do_GetInterface (mWebBrowser);
-	NS_ENSURE_TRUE (ds, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIDocumentCharsetInfo> ci;
-	result = ds->GetDocumentCharsetInfo (getter_AddRefs (ci));
-	NS_ENSURE_TRUE (ci, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIAtom> atom;
-	ci->GetForcedCharset (getter_AddRefs (atom));
-	if (atom)
-	{
-		nsCAutoString atomstr;
-		atom->ToUTF8String (atomstr);
-		info->forced_encoding = g_strdup (atomstr.get());
-	}
-
-	ci->GetParentCharset (getter_AddRefs (atom));
-	if (atom)
-	{
-		nsCAutoString atomstr;
-		atom->ToUTF8String (atomstr);
-		info->parent_encoding = g_strdup (atomstr.get());
-	}
-
-	result = ci->GetParentCharsetSource (&source);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
-	info->parent_encoding_source = (EphyEncodingSource) source;
-
-	nsCOMPtr<nsIContentViewer> contentViewer;	
-	ds->GetContentViewer (getter_AddRefs(contentViewer));
-	NS_ENSURE_TRUE (contentViewer, NS_ERROR_FAILURE);
-
-	nsCOMPtr<nsIMarkupDocumentViewer> mdv = do_QueryInterface(contentViewer);
-	NS_ENSURE_TRUE (mdv, NS_ERROR_FAILURE);
-
-#if MOZILLA_SNAPSHOT > 11
-	const nsACString& charsetEnc = doc->GetDocumentCharacterSet ();
-	NS_ENSURE_TRUE (!charsetEnc.IsEmpty(), NS_ERROR_FAILURE);
-
-	info->encoding = g_strdup (PromiseFlatCString(charsetEnc).get());
-#elif MOZILLA_SNAPSHOT >= 10
-	nsCAutoString charsetEnc;	
-	result = doc->GetDocumentCharacterSet (charsetEnc);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
-
-	info->encoding = g_strdup (charsetEnc.get());
-#else
-	nsAutoString charsetEnc;
-	result = doc->GetDocumentCharacterSet (charsetEnc);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
-
-	info->encoding = g_strdup (NS_ConvertUCS2toUTF8(charsetEnc).get());
-#endif
-
-#if MOZILLA_SNAPSHOT >= 10
-	nsCAutoString enc;
-	
-	result = mdv->GetDefaultCharacterSet (enc);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
-	info->default_encoding = g_strdup (enc.get());
-
-	result = mdv->GetForceCharacterSet (enc);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
-	info->forced_encoding = g_strdup (enc.get());
-
-	result = mdv->GetHintCharacterSet (enc);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
-	info->hint_encoding = g_strdup (enc.get());
-
-	result = mdv->GetPrevDocCharacterSet (enc);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
-	info->prev_doc_encoding = g_strdup (enc.get());
-#else
-	PRUnichar *str;
-
-	result = mdv->GetDefaultCharacterSet (&str);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
-	info->default_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
-
-	result = mdv->GetForceCharacterSet (&str);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
-	info->forced_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
-
-	result = mdv->GetHintCharacterSet (&str);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
-	info->hint_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
-
-	result = mdv->GetPrevDocCharacterSet (&str);
-	if (NS_FAILED (result)) return NS_ERROR_FAILURE;
-	info->prev_doc_encoding = g_strdup (NS_ConvertUCS2toUTF8(str).get());
-#endif
-
-	mdv->GetHintCharacterSetSource (&source);
-	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
-	info->hint_encoding_source = (EphyEncodingSource) source;
-
-	return NS_OK;
-}
-
 nsresult EphyBrowser::DoCommand (const char *command)
 {
-	nsCOMPtr<nsICommandManager> cmdManager;
-
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
+	nsCOMPtr<nsICommandManager> cmdManager;
 	cmdManager = do_GetInterface (mWebBrowser);
 	NS_ENSURE_TRUE (cmdManager, NS_ERROR_FAILURE);
 
@@ -850,10 +729,9 @@ nsresult EphyBrowser::DoCommand (const char *command)
 
 nsresult EphyBrowser::GetCommandState (const char *command, PRBool *enabled)
 {
-	nsCOMPtr<nsICommandManager> cmdManager;
-
 	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
 
+	nsCOMPtr<nsICommandManager> cmdManager;
 	cmdManager = do_GetInterface (mWebBrowser);
 	NS_ENSURE_TRUE (cmdManager, NS_ERROR_FAILURE);
 
@@ -964,6 +842,8 @@ nsresult EphyBrowser::GetHasModifiedForms (PRBool *modified)
 {
 	*modified = PR_FALSE;
 
+	NS_ENSURE_TRUE (mWebBrowser, NS_ERROR_FAILURE);
+
 	nsCOMPtr<nsIDocShell> rootDocShell = do_GetInterface (mWebBrowser);
 	NS_ENSURE_TRUE (rootDocShell, NS_ERROR_FAILURE);
 
