@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyBrowser.h,v 1.10.4.3 2004/07/31 15:37:54 chpe Exp $
+ *  $Id: EphyBrowser.h,v 1.15 2004/05/23 01:06:34 marco Exp $
  */
 
 #ifndef EPHY_BROWSER_H
@@ -24,21 +24,24 @@
 #include "ephy-encodings.h"
 #include "ephy-embed.h"
 
-#include "nsIDOMEventListener.h"
-#include "nsIDocShell.h"
-#include "nsIWebNavigation.h"
-#include "nsIWebPageDescriptor.h"
-#include "nsISHistory.h"
-#include "nsIWebBrowser.h"
-#include "nsIWebProgressListener.h"
-#include "nsCOMPtr.h"
-#include "nsIDOMEventReceiver.h"
-#include "nsIDOMDocument.h"
-#include "nsIDOMWindow.h"
-#include "nsPIDOMWindow.h"
 #include <gtkmozembed.h>
+#include <nsCOMPtr.h>
+#include <nsIDOMEventListener.h>
+#include <nsIWebNavigation.h>
+#include <nsISHistory.h>
+#include <nsIWebBrowser.h>
+#include <nsIDOMDocument.h>
+#include <nsIDOMWindow.h>
+#include <nsIPrintSettings.h>
 
-#include "nsIPrintSettings.h"
+#ifdef ALLOW_PRIVATE_STRINGS
+#include "nsString.h"
+#endif
+
+#ifdef ALLOW_PRIVATE_API
+#include <nsIDocShell.h>
+#include <nsIDOMEventReceiver.h>
+#endif
 
 class EphyEventListener : public nsIDOMEventListener
 {
@@ -67,12 +70,6 @@ private:
 	nsresult HandleFaviconLink (nsIDOMNode *node);
 };
 
-class EphyPopupEventListener : public EphyEventListener
-{
-public:
-	NS_IMETHOD HandleEvent(nsIDOMEvent* aEvent);
-};
-
 class EphyBrowser
 {
 public:
@@ -88,8 +85,9 @@ public:
 	nsresult SetZoom (float aTextZoom, PRBool reflow);
 	nsresult GetZoom (float *aTextZoom);
 
-	nsresult Print ();
-	nsresult SetPrintPreviewMode (PRBool previewMode);
+	nsresult Print (nsIPrintSettings *options, PRBool preview);
+	nsresult GetPrintSettings (nsIPrintSettings * *options);
+	nsresult PrintPreviewClose (void);
 	nsresult PrintPreviewNumPages (int *numPages);
 	nsresult PrintPreviewNavigate(PRInt16 navType, PRInt32 pageNum);
 
@@ -103,26 +101,20 @@ public:
 
 	nsresult GetSHInfo (PRInt32 *count, PRInt32 *index);
 	nsresult GetSHTitleAtIndex (PRInt32 index, PRUnichar **title);
-	nsresult GetSHUrlAtIndex (PRInt32 index, nsACString &url);
+	nsresult GetSHUrlAtIndex (PRInt32 index, nsCString &url);
 	nsresult GoToHistoryIndex (PRInt16 index);
 
-	enum { RELOAD_NORMAL = 0 };
-	enum { RELOAD_FORCE = 1 };
-	enum { RELOAD_ENCODING_CHANGE = 2 };
-
-	nsresult Reload (PRUint32 flags);
-
 	nsresult ForceEncoding (const char *encoding);
-
-	nsresult GetEncodingInfo (EphyEncodingInfo **infoptr);
+	nsresult GetEncoding (nsACString &encoding);
+	nsresult GetForcedEncoding (nsACString &encoding);
 
 	nsresult PushTargetDocument (nsIDOMDocument *domDoc);
 	nsresult PopTargetDocument ();
 
 	nsresult GetDocument (nsIDOMDocument **aDOMDocument);
 	nsresult GetTargetDocument (nsIDOMDocument **aDOMDocument);
-	nsresult GetDocumentUrl (nsACString &url);
-	nsresult GetTargetDocumentUrl (nsACString &url);
+	nsresult GetDocumentUrl (nsCString &url);
+	nsresult GetTargetDocumentUrl (nsCString &url);
 
 	nsresult GetHasModifiedForms (PRBool *modified);
 
@@ -130,11 +122,9 @@ public:
 
 private:
 	nsCOMPtr<nsIDOMDocument> mTargetDocument;
-	nsCOMPtr<nsIWebProgressListener> mProgress;
 	nsCOMPtr<nsIDOMEventReceiver> mEventReceiver;
 	nsCOMPtr<nsIDOMWindow> mDOMWindow;
 	EphyFaviconEventListener *mFaviconEventListener;
-	EphyPopupEventListener *mPopupEventListener;
 	PRBool mInitialized;
 
 	nsresult GetListener (void);
