@@ -1,5 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.cpp,v 1.24 2004/02/06 22:06:42 chpe Exp $
+ *  $Id: EventContext.cpp,v 1.30 2004/04/29 19:22:07 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -23,29 +24,36 @@
 #endif
 
 #include "EventContext.h"
-#include "nsIDOMEventTarget.h"
-#include "nsIDocument.h"
-#include "nsIDOMHTMLInputElement.h"
-#include "nsIDOMHTMLObjectElement.h"
-#include "nsIInterfaceRequestor.h"
-#include "nsIDOMHTMLImageElement.h"
-#include "nsIDOMElement.h"
-#include "nsIDOMXULDocument.h"
-#include "nsIURI.h"
-#include "nsNetUtil.h"
-#include "nsIDOMNSDocument.h"
-#include "nsReadableUtils.h"
-#include "nsUnicharUtils.h"
-#include "nsGUIEvent.h"
-#include "nsIDOMNSEvent.h"
-#include "nsIDOMCharacterData.h"
-#include "nsIDOMHTMLButtonElement.h"
-#include "nsIDOMHTMLLabelElement.h"
-#include "nsIDOMHTMLLegendElement.h"
-#include "nsIDOMHTMLTextAreaElement.h"
+
 #include <gdk/gdkkeysyms.h>
-#include "nsIPrivateDOMEvent.h"
-#include "nsIDOMNSUIEvent.h"
+
+#include <nsIInterfaceRequestor.h>
+#include <nsIDOMEventTarget.h>
+#include <nsIDOMHTMLInputElement.h>
+#include <nsIDOMHTMLObjectElement.h>
+#include <nsIDOMHTMLImageElement.h>
+#include <nsIDOMElement.h>
+#include <nsIURI.h>
+#include <nsIDOMCharacterData.h>
+#include <nsIDOMHTMLButtonElement.h>
+#include <nsIDOMHTMLLabelElement.h>
+#include <nsIDOMHTMLLegendElement.h>
+#include <nsIDOMHTMLTextAreaElement.h>
+#include <nsIDOMElementCSSInlineStyle.h>
+#include <nsIDOMCSSStyleDeclaration.h>
+
+#ifdef ALLOW_PRIVATE_API
+#include <nsIDOMXULDocument.h>
+#include <nsIDOMNSEvent.h>
+#include <nsIDOMNSHTMLElement.h>
+#endif
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include <nsIDocument.h>
+#include <nsReadableUtils.h>
+#include <nsNetUtil.h>
+#endif
+
 
 #define KEY_CODE 256
 
@@ -145,7 +153,6 @@ nsresult EventContext::GatherTextUnder (nsIDOMNode* aNode, nsString& aResult)
 
 nsresult EventContext::ResolveBaseURL (nsIDocument *doc, const nsAString &relurl, nsACString &url)
 {
-	nsresult rv;
 #if MOZILLA_SNAPSHOT > 13
 	nsIURI *base;
 	base = doc->GetBaseURI ();
@@ -154,22 +161,13 @@ nsresult EventContext::ResolveBaseURL (nsIDocument *doc, const nsAString &relurl
 	nsIURI *base;
 	base = doc->GetBaseURL ();
 	if (!base) return NS_ERROR_FAILURE;
-#elif MOZILLA_SNAPSHOT > 9 
-	nsCOMPtr<nsIURI> base;
-	rv = doc->GetBaseURL (getter_AddRefs(base));
-	if (NS_FAILED(rv)) return rv;
-#else
-	nsCOMPtr<nsIURI> base;
-	rv = doc->GetBaseURL (*getter_AddRefs(base));
-	if (NS_FAILED(rv)) return rv;
 #endif
 
-	return base->Resolve (NS_ConvertUCS2toUTF8(relurl), url);
+	return base->Resolve (NS_ConvertUTF16toUTF8(relurl), url);
 }
 
 nsresult EventContext::ResolveDocumentURL (nsIDocument *doc, const nsAString &relurl, nsACString &url)
 {
-	nsresult rv;
 #if MOZILLA_SNAPSHOT > 13
 	nsIURI *uri;
 	uri = doc->GetDocumentURI ();
@@ -178,13 +176,9 @@ nsresult EventContext::ResolveDocumentURL (nsIDocument *doc, const nsAString &re
 	nsIURI *uri;
 	uri = doc->GetDocumentURL ();
 	if (!uri) return NS_ERROR_FAILURE;
-#else
-	nsCOMPtr<nsIURI> uri;
-	rv = doc->GetDocumentURL(getter_AddRefs(uri));
-	if (NS_FAILED(rv)) return rv;
 #endif
 
-	return uri->Resolve (NS_ConvertUCS2toUTF8(relurl), url);
+	return uri->Resolve (NS_ConvertUTF16toUTF8(relurl), url);
 }
 
 nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
@@ -235,8 +229,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 		rv = element->GetTagName(tag);
 		if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
 
-		if (tag.Equals(NS_LITERAL_STRING("img"),
-			       nsCaseInsensitiveStringComparator()))
+		if (tag.EqualsIgnoreCase("img"))
 		{
 			info->context |= EMBED_CONTEXT_IMAGE;
 
@@ -262,7 +255,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
                                 rv = ResolveDocumentURL (doc, img, imglongdesc);
                                                                                                                 
                                 SetStringProperty ("image_long_desc",
-                                                   NS_ConvertUTF8toUCS2(imglongdesc));
+                                                   NS_ConvertUTF8toUTF16(imglongdesc));
 			}
 
 			int imgwidth, imgheight;
@@ -278,8 +271,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 						   img);
 			}
 		}
-		else if (tag.Equals(NS_LITERAL_STRING("input"),
-				    nsCaseInsensitiveStringComparator()))
+		else if (tag.EqualsIgnoreCase("input"))
 		{
 			nsCOMPtr<nsIDOMElement> element;
 			element = do_QueryInterface (node);
@@ -289,8 +281,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 			nsAutoString value;
 			element->GetAttribute (attr, value);
 
-			if (value.Equals(NS_LITERAL_STRING("image"),
-					 nsCaseInsensitiveStringComparator()))
+			if (value.EqualsIgnoreCase("image"))
 			{
 				info->context |= EMBED_CONTEXT_IMAGE;
 				nsCOMPtr<nsIDOMHTMLInputElement> input;
@@ -305,31 +296,23 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 				rv = ResolveDocumentURL (doc, img, cImg);
                                 if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
 				SetStringProperty ("image",
-						   NS_ConvertUTF8toUCS2(cImg));
+						   NS_ConvertUTF8toUTF16(cImg));
 			}
-			else if (!value.Equals(NS_LITERAL_STRING("radio"),
-					       nsCaseInsensitiveStringComparator()) &&
-				 !value.Equals(NS_LITERAL_STRING("submit"),
-					       nsCaseInsensitiveStringComparator()) &&
-				 !value.Equals(NS_LITERAL_STRING("reset"),
-					       nsCaseInsensitiveStringComparator()) &&
-				 !value.Equals(NS_LITERAL_STRING("hidden"),
-					       nsCaseInsensitiveStringComparator()) &&
-				 !value.Equals(NS_LITERAL_STRING("button"),
-					       nsCaseInsensitiveStringComparator()) &&
-				 !value.Equals(NS_LITERAL_STRING("checkbox"),
-					       nsCaseInsensitiveStringComparator()))
+			else if (!value.EqualsIgnoreCase("radio")  &&
+				 !value.EqualsIgnoreCase("submit") &&
+				 !value.EqualsIgnoreCase("reset")  &&
+				 !value.EqualsIgnoreCase("hidden") &&
+				 !value.EqualsIgnoreCase("button") &&
+				 !value.EqualsIgnoreCase("checkbox"))
 			{
 				info->context |= EMBED_CONTEXT_INPUT;
 			}
 		}
-		else if (tag.Equals(NS_LITERAL_STRING("textarea"),
-				    nsCaseInsensitiveStringComparator()))
+		else if (tag.EqualsIgnoreCase("textarea"))
 		{
 			info->context |= EMBED_CONTEXT_INPUT;
 		}
-		else if (tag.Equals(NS_LITERAL_STRING("object"),
-				    nsCaseInsensitiveStringComparator()))
+		else if (tag.EqualsIgnoreCase("object"))
 		{
 			nsCOMPtr<nsIDOMHTMLObjectElement> object;
 			object = do_QueryInterface (node);
@@ -338,11 +321,8 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 			nsAutoString value;
 			object->GetType(value);
 
-			//Forming a substring and confirming it's contents
-			//is quicker than doing a Find on the full string
-			//and then checking that "image/" is at the beginning
-			if (Substring(value, 0, 6).Equals(NS_LITERAL_STRING("image/"),
-			    nsCaseInsensitiveStringComparator()))
+			// MIME types are always lower case
+			if (Substring (value, 0, 6).Equals(NS_LITERAL_STRING("image/")))
 			{
 				info->context |= EMBED_CONTEXT_IMAGE;
 				
@@ -382,8 +362,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 			nsAutoString value;
 			dom_elem->GetAttributeNS (nspace, localname_type, value);
 
-			if (value.Equals(NS_LITERAL_STRING("simple"),
-					 nsCaseInsensitiveStringComparator()))
+			if (value.EqualsIgnoreCase("simple"))
 			{
 				info->context |= EMBED_CONTEXT_LINK;
 				NS_NAMED_LITERAL_STRING (localname_href, "href");
@@ -406,10 +385,10 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 			if (NS_FAILED(rv)) return NS_ERROR_FAILURE;
 
 			/* Link */
-			if (tag.Equals(NS_LITERAL_STRING("a"),
-				       nsCaseInsensitiveStringComparator()))
+			if (tag.EqualsIgnoreCase("a"))
 			{
 				nsAutoString tmp;
+				nsAutoString substr;
 
 				rv = GatherTextUnder (node, tmp);
 				if (NS_SUCCEEDED(rv))
@@ -417,17 +396,15 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 
 				nsCOMPtr <nsIDOMHTMLAnchorElement> anchor =
 					do_QueryInterface(node);
-				rv = anchor->GetHref (tmp);
-				if (NS_FAILED(rv))
-					return NS_ERROR_FAILURE;
 
-				if (Substring(tmp, 0, 7).Equals(NS_LITERAL_STRING("mailto:"),
-			    	    nsCaseInsensitiveStringComparator()))
+				anchor->GetHref (tmp);
+				substr.Assign (Substring (tmp, 0, 7));
+				if (substr.EqualsIgnoreCase("mailto:"))
 				{
 					info->context |= EMBED_CONTEXT_EMAIL_LINK;
 					const nsAString &address = Substring(tmp, 7, tmp.Length()-7);
 					SetStringProperty ("email", address);
-				}	
+				}
 				
 				if (anchor && !tmp.IsEmpty()) 
 				{
@@ -454,8 +431,7 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 					if (NS_SUCCEEDED(rv))
 						SetStringProperty ("link_type", tmp);
 
-					if (tmp.Equals(NS_LITERAL_STRING("text/smartbookmark"),
-						       nsCaseInsensitiveStringComparator()))
+					if (tmp.EqualsIgnoreCase("text/smartbookmark"))
 					{
 						SetIntProperty ("link_is_smart", TRUE);
 						
@@ -484,14 +460,12 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 				}
 			
 			}
-			else if (tag.Equals(NS_LITERAL_STRING("option"),
-					    nsCaseInsensitiveStringComparator()))
+			else if (tag.EqualsIgnoreCase("option"))
 			{
 				info->context = EMBED_CONTEXT_NONE;
 				return NS_OK;
 			}
-			if (tag.Equals(NS_LITERAL_STRING("area"),
-				       nsCaseInsensitiveStringComparator()))
+			if (tag.EqualsIgnoreCase("area"))
 			{
 				info->context |= EMBED_CONTEXT_LINK;
 				nsCOMPtr <nsIDOMHTMLAreaElement> area =
@@ -507,10 +481,8 @@ nsresult EventContext::GetEventContext (nsIDOMEventTarget *EventTarget,
 					CheckLinkScheme (href);
 				}
 			}
-			else if (tag.Equals(NS_LITERAL_STRING("textarea"),
-					    nsCaseInsensitiveStringComparator()) ||
-				 tag.Equals(NS_LITERAL_STRING("input"),
-					    nsCaseInsensitiveStringComparator()))
+			else if (tag.EqualsIgnoreCase("textarea") ||
+				 tag.EqualsIgnoreCase("input"))
 			{
 				info->context |= EMBED_CONTEXT_INPUT;
 			}
@@ -674,16 +646,11 @@ nsresult EventContext::GetMouseEventInfo (nsIDOMMouseEvent *aMouseEvent, Mozilla
 	nsAutoString nodename;
 	OriginalNode->GetNodeName(nodename);
 
-	if (nodename.Equals(NS_LITERAL_STRING("xul:scrollbarbutton"),
-			    nsCaseInsensitiveStringComparator()) ||
-	    nodename.Equals(NS_LITERAL_STRING("xul:thumb"),
-			    nsCaseInsensitiveStringComparator()) ||
-	    nodename.Equals(NS_LITERAL_STRING("xul:vbox"),
-			    nsCaseInsensitiveStringComparator()) ||
-	    nodename.Equals(NS_LITERAL_STRING("xul:spacer"),
-			    nsCaseInsensitiveStringComparator()) ||
-	    nodename.Equals(NS_LITERAL_STRING("xul:slider"),
-			    nsCaseInsensitiveStringComparator()))
+	if (nodename.EqualsIgnoreCase("xul:scrollbarbutton") ||
+	    nodename.EqualsIgnoreCase("xul:thumb")	     ||
+	    nodename.EqualsIgnoreCase("xul:vbox")	     ||
+	    nodename.EqualsIgnoreCase("xul:spacer")	     ||
+	    nodename.EqualsIgnoreCase("xul:slider"))
 		return NS_ERROR_FAILURE;
 
 	nsCOMPtr<nsIDOMEventTarget> EventTarget;
@@ -813,12 +780,13 @@ nsresult EventContext::CheckLinkScheme (const nsAString &link)
 	rv = uri->GetScheme (scheme);
 	if (NS_FAILED (rv)) return NS_ERROR_FAILURE;
 
-	if (scheme.EqualsIgnoreCase ("http")  ||
-	    scheme.EqualsIgnoreCase ("https") ||
-	    scheme.EqualsIgnoreCase ("ftp")   ||
-	    scheme.EqualsIgnoreCase ("file")  ||
-	    scheme.EqualsIgnoreCase ("data")  ||
-	    scheme.EqualsIgnoreCase ("about") ||
+	if (scheme.EqualsIgnoreCase ("http")	 ||
+	    scheme.EqualsIgnoreCase ("https")	 ||
+	    scheme.EqualsIgnoreCase ("ftp")	 ||
+	    scheme.EqualsIgnoreCase ("file")	 ||
+	    scheme.EqualsIgnoreCase ("data")	 ||
+	    scheme.EqualsIgnoreCase ("resource") ||
+	    scheme.EqualsIgnoreCase ("about")	 ||
 	    scheme.EqualsIgnoreCase ("gopher"))
 	{
 		SetIntProperty ("link-has-web-scheme", TRUE);
@@ -856,5 +824,5 @@ nsresult EventContext::SetStringProperty (const char *name, const char *value)
 
 nsresult EventContext::SetStringProperty (const char *name, const nsAString &value)
 {
-	return SetStringProperty (name, NS_ConvertUCS2toUTF8(value).get());
+	return SetStringProperty (name, NS_ConvertUTF16toUTF8(value).get());
 }
