@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: FilePicker.cpp,v 1.26.4.6 2004/06/07 14:33:16 chpe Exp $
+ *  $Id: FilePicker.cpp,v 1.37 2004/05/08 20:11:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -35,8 +35,10 @@
 #include <nsIDOMWindow.h>
 #include <nsNetCID.h>
 
+#ifdef ALLOW_PRIVATE_STRINGS
 #include <nsString.h>
 #include <nsReadableUtils.h>
+#endif
 
 #if MOZILLA_SNAPSHOT < 18
 #include <nsIDOMWindowInternal.h>
@@ -95,10 +97,10 @@ NS_IMETHODIMP GFilePicker::Init(nsIDOMWindow *parent, const nsAString& title, PR
 		gtk_window_set_transient_for (GTK_WINDOW (mDialog), GTK_WINDOW (pwin));
 	}
 
-#if MOZILLA_SNAPSHOT < 13
-	gtk_window_set_title (GTK_WINDOW (mDialog), NS_ConvertUCS2toUTF8(title).get());
-#else
+#if MOZILLA_SNAPSHOT < 18
 	gtk_window_set_title (GTK_WINDOW (mDialog), NS_ConvertUTF16toUTF8 (title).get());
+#else
+	gtk_window_set_title (GTK_WINDOW (mDialog), NS_ConvertUCS2toUTF8(title).get());
 #endif
 
 	mMode = mode;
@@ -155,69 +157,43 @@ NS_IMETHODIMP GFilePicker::AppendFilters(PRInt32 filterMask)
 	// http://lxr.mozilla.org/seamonkey/source/xpfe/components/filepicker/res/locale/en-US/filepicker.properties
 	// http://lxr.mozilla.org/seamonkey/source/xpfe/components/filepicker/src/nsFilePicker.js line 131 ff
 
-	// FIXME: use filters with mimetypes instead of extensions
-
 	LOG ("GFilePicker::AppendFilters mask=%d", filterMask)
 
 	if (filterMask & nsIFilePicker::filterAll)
 	{
-#if MOZILLA_SNAPSHOT < 18
-		AppendFilter (NS_ConvertUTF8toUCS2 (_("All files")).get(),
-			      NS_LITERAL_STRING ("*").get());
-#else
-		AppendFilter (NS_ConvertUTF8toUTF16 (_("All files")),
-			      NS_LITERAL_STRING ("*"));
-#endif
+		ephy_file_chooser_add_pattern_filter (mDialog, _("All files"),
+						      "*", NULL);
 	}
 	if (filterMask & nsIFilePicker::filterHTML)
 	{
-#if MOZILLA_SNAPSHOT < 18
-		AppendFilter (NS_ConvertUTF8toUCS2 (_("HTML files")).get(),
-			      NS_LITERAL_STRING ("*.html; *.htm; *.shtml; *.xhtml").get());
-#else
-		AppendFilter (NS_ConvertUTF8toUTF16 (_("HTML files")),
-			      NS_LITERAL_STRING ("*.html; *.htm; *.shtml; *.xhtml"));
-#endif
+		ephy_file_chooser_add_mime_filter (mDialog, _("Web pages"),
+						   "text/html",
+						   "application/xhtml+xml",
+						   "text/xml",
+						   NULL);
 	}
 	if (filterMask & nsIFilePicker::filterText)
 	{
-#if MOZILLA_SNAPSHOT < 18
-		AppendFilter (NS_ConvertUTF8toUCS2 (_("Text files")).get(),
-			      NS_LITERAL_STRING ("*.txt; *.text").get());
-#else
-		AppendFilter (NS_ConvertUTF8toUTF16 (_("Text files")),
-			      NS_LITERAL_STRING ("*.txt; *.text"));
-#endif
+		ephy_file_chooser_add_pattern_filter (mDialog, _("Text files"),
+						      "*.txt", "*.text", NULL);
 	}
 	if (filterMask & nsIFilePicker::filterImages)
 	{
-#if MOZILLA_SNAPSHOT < 18
-		AppendFilter (NS_ConvertUTF8toUCS2 (_("Image files")).get(),
-			      NS_LITERAL_STRING ("*.png; *.gif; *.jpeg; *.jpg").get());
-#else
-		AppendFilter (NS_ConvertUTF8toUTF16 (_("Image files")),
-			      NS_LITERAL_STRING ("*.png; *.gif; *.jpeg; *.jpg"));
-#endif
+		ephy_file_chooser_add_mime_filter (mDialog, _("Images"),
+						   "image/png",
+						   "image/jpeg",
+						   "image/gif",
+						   NULL);
 	}
 	if (filterMask & nsIFilePicker::filterXML)
 	{
-#if MOZILLA_SNAPSHOT < 18
-		AppendFilter (NS_ConvertUTF8toUCS2 (_("XML files")).get(),
-			      NS_LITERAL_STRING ("*.xml").get());
-#else
-		AppendFilter (NS_ConvertUTF8toUTF16 (_("XML files")),
-			      NS_LITERAL_STRING ("*.xml"));
-#endif
+		ephy_file_chooser_add_pattern_filter (mDialog, _("XML files"),
+						      "*.xml", NULL);
 	}
 	if (filterMask & nsIFilePicker::filterXUL)
 	{
-#if MOZILLA_SNAPSHOT < 18
-		AppendFilter (NS_ConvertUTF8toUCS2 (_("XUL files")).get(),
-			      NS_LITERAL_STRING ("*.xul").get());
-#else
-		AppendFilter (NS_ConvertUTF8toUTF16 (_("XUL files")),
-			      NS_LITERAL_STRING ("*.xul"));
-#endif
+		ephy_file_chooser_add_pattern_filter (mDialog, _("XUL files"),
+						      "*.xul", NULL);
 	}
 
 	return NS_OK;
@@ -231,31 +207,28 @@ NS_IMETHODIMP GFilePicker::AppendFilter(const nsAString& title, const nsAString&
 #endif
 {
 	LOG ("GFilePicker::AppendFilter title '%s' for '%s'",
-	     NS_ConvertUCS2toUTF8 (title).get(),
-	     NS_ConvertUCS2toUTF8 (filter).get())
+	     NS_ConvertUTF16toUTF8 (title).get(),
+	     NS_ConvertUTF16toUTF8 (filter).get())
 
-#if MOZILLA_SNAPHOST < 13
-	NS_ConvertUCS2toUTF8 pattern(filter);
-#else
 	NS_ConvertUTF16toUTF8 pattern(filter);
-#endif
+
 	pattern.StripWhitespace();
 	if (pattern.IsEmpty()) return NS_ERROR_FAILURE;
 
-	char **patterns = g_strsplit (pattern.get(), ";", -1);
+	char **patterns;
+	patterns = g_strsplit (pattern.get(), ";", -1);
+	if (!patterns) return NS_ERROR_FAILURE;
 
-	GtkFileFilter *filth = gtk_file_filter_new ();
+	GtkFileFilter *filth;
+	filth = gtk_file_filter_new ();
 
 	for (int i = 0; patterns[i] != NULL; i++)
 	{
 		gtk_file_filter_add_pattern (filth, patterns[i]);
 	}
 
-#if MOZILLA_SNAPHOST < 13
-	gtk_file_filter_set_name (filth, NS_ConvertUCS2toUTF8(title).get());
-#else
-	gtk_file_filter_set_name (filth, NS_ConvertUTF16toUTF8(title).get());
-#endif
+	gtk_file_filter_set_name (filth, NS_ConvertUTF16toUTF8 (title).get());
+
 	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (mDialog), filth);
 
 	g_strfreev (patterns);
@@ -270,13 +243,24 @@ NS_IMETHODIMP GFilePicker::GetDefaultString(PRUnichar **aDefaultString)
 NS_IMETHODIMP GFilePicker::GetDefaultString(nsAString& aDefaultString)
 #endif
 {
+	char *filename, *converted;
+
 	LOG ("GFilePicker::GetDefaultString")
 
+	filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (mDialog));
+	if (filename != NULL)
+	{
+		converted = g_filename_to_utf8(filename, -1, NULL, NULL, NULL);
+
 #if MOZILLA_SNAPSHOT < 18
-	*aDefaultString = ToNewUnicode (mDefaultString);
+		*aDefaultString = ToNewUnicode (NS_ConvertUTF8toUTF16 (converted));
 #else
-	aDefaultString = mDefaultString;
+		CopyUTF8toUTF16 (converted, aDefaultString);
 #endif
+	
+		g_free (filename);
+		g_free (converted);
+	}
 
 	return NS_OK;
 }
@@ -287,23 +271,24 @@ NS_IMETHODIMP GFilePicker::SetDefaultString(const PRUnichar *aDefaultString)
 NS_IMETHODIMP GFilePicker::SetDefaultString(const nsAString& aDefaultString)
 #endif
 {
+#if MOZILLA_SNAPSHOT < 18
+	LOG ("GFilePicker::SetDefaultString to %s",
+	     NS_ConvertUTF16toUTF8 (aDefaultString).get())
+#else
 	LOG ("GFilePicker::SetDefaultString to %s",
 	     NS_ConvertUCS2toUTF8 (aDefaultString).get())
+#endif
 
-	mDefaultString.Assign (aDefaultString);
-
-	if (mMode == nsIFilePicker::modeSave)
+#if MOZILLA_SNAPSHOT < 18
+	if (aDefaultString)
+#else
+	if (aDefaultString.Length())
+#endif
 	{
 		/* set_current_name takes UTF-8, not a filename */
-#if MOZILLA_SNAPSHOT < 13
 		gtk_file_chooser_set_current_name
 			(GTK_FILE_CHOOSER (mDialog),
-			 NS_ConvertUCS2toUTF8 (mDefaultString).get());
-#else
-		gtk_file_chooser_set_current_name
-			(GTK_FILE_CHOOSER (mDialog),
-			 NS_ConvertUTF16toUTF8 (mDefaultString).get());
-#endif
+			 NS_ConvertUTF16toUTF8 (aDefaultString).get());
 	}
 
 	return NS_OK;
@@ -328,7 +313,7 @@ NS_IMETHODIMP GFilePicker::SetDefaultExtension(const nsAString& aDefaultExtensio
 #endif
 {
 	LOG ("GFilePicker::SetDefaultExtension to %s",
-	     NS_ConvertUCS2toUTF8(aDefaultExtension).get())
+	     NS_ConvertUTF16toUTF8(aDefaultExtension).get())
 
 	return NS_ERROR_NOT_IMPLEMENTED;
 }
@@ -376,26 +361,8 @@ NS_IMETHODIMP GFilePicker::SetDisplayDirectory(nsILocalFile *aDisplayDirectory)
 
 	LOG ("GFilePicker::SetDisplayDirectory to %s", dir.get())
 
-	if (!mDefaultString.IsEmpty() && mMode != nsIFilePicker::modeSave)
-	{
-		char *defaultString, *filename;
-
-		defaultString = g_filename_from_utf8 (NS_ConvertUCS2toUTF8(mDefaultString).get(),
-						      -1, NULL, NULL, NULL);
-		if (defaultString)
-		{
-			filename = g_build_filename (dir.get(), defaultString, NULL);
-			gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (mDialog), filename);
-			g_free (filename);
-		}
-		g_free (defaultString);
-
-	}
-	else
-	{
-		gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (mDialog),
-						     dir.get());
-	}
+	gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (mDialog),
+					     dir.get());
 
 	return NS_OK;
 }
