@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed-single.cpp,v 1.69.4.5 2004/07/25 11:06:43 chpe Exp $
+ *  $Id: mozilla-embed-single.cpp,v 1.73 2004/05/06 13:29:20 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -43,46 +43,41 @@
 
 #include <glib/gi18n.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
-#include <nsICacheService.h>
+
 #include <nsCOMPtr.h>
 #include <nsIPrefService.h>
-#include <nsNetCID.h>
 #include <nsIServiceManager.h>
 #include <nsIIOService.h>
-#include <nsIProtocolProxyService.h>
-#include <nsIAtom.h>
-#include <nsIFontEnumerator.h>
 #include <nsISupportsPrimitives.h>
-#include <nsReadableUtils.h>
 #include <nsICookieManager.h>
-#include <nsIPassword.h>
-#include <nsIPasswordManager.h>
-#include <nsIPassword.h>
-#if MOZILLA_SNAPSHOT > 9
 #include <nsICookie2.h>
-#else
-#include <nsICookie.h>
-#endif
-#if MOZILLA_SNAPSHOT > 12
 #include <nsICookieManager.h>
-#else
-#include <nsCCookieManager.h>
-#endif
+#include <nsIPasswordManager.h>
 #include <nsCPasswordManager.h>
 #include <nsIPermission.h>
 #include <nsIPermissionManager.h>
-#include <nsString.h>
 #include <nsILocalFile.h>
 #include <nsIURI.h>
-#include <nsNetUtil.h>
-#include <nsIHttpAuthManager.h>
-#include <nsIPrintSettings.h>
-#include <nsIPrintSettingsService.h>
-#include <nsIPrintingPromptService.h>
 
+#ifdef HAVE_NSIPASSWORD_H
+#include <nsIPassword.h>
+#endif
+
+#ifdef ALLOW_PRIVATE_API
 // FIXME: For setting the locale. hopefully gtkmozembed will do itself soon
 #include <nsIChromeRegistry.h>
 #include <nsILocaleService.h>
+#include <nsIProtocolProxyService.h>
+#include <nsIHttpAuthManager.h>
+#include <nsICacheService.h>
+#include <nsIFontEnumerator.h>
+#endif
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include <nsString.h>
+#include <nsReadableUtils.h>
+#include <nsNetUtil.h>
+#endif
 
 #define MOZILLA_PROFILE_DIR  "/mozilla"
 #define MOZILLA_PROFILE_NAME "epiphany"
@@ -224,9 +219,18 @@ mozilla_set_default_prefs (MozillaEmbedSingle *mes)
 	pref->SetCharPref ("general.useragent.vendor", "Epiphany");
 	pref->SetCharPref ("general.useragent.vendorSub", VERSION);
 
-	/* Open ftp uris with an external handler if one is setup */
-	pref->SetBoolPref("network.protocol-handler.external.ftp",
-			  have_gnome_url_handler ("ftp"));
+	/* Make sure that Mozilla does not handle these protocols internally */
+	pref->SetBoolPref("network.protocol-handler.external.news", TRUE);
+	pref->SetBoolPref("network.protocol-handler.external.mailto", TRUE);
+	pref->SetBoolPref("network.protocol-handler.external.irc", TRUE);
+	if (have_gnome_url_handler ("ftp"))
+	{
+		pref->SetBoolPref("network.protocol-handler.external.ftp", TRUE);
+	}
+	else
+	{
+		pref->SetBoolPref("network.protocol-handler.external.ftp", FALSE);
+	}
 
 	return TRUE;
 }
@@ -379,13 +383,7 @@ getUILang (nsAString& aUILang)
 		return NS_ERROR_FAILURE;
 	}
 
-#if MOZILLA_SNAPSHOT >= 12
 	result = localeService->GetLocaleComponentForUserAgent (aUILang);
-#else
-	nsXPIDLString uiLang;
-	result = localeService->GetLocaleComponentForUserAgent (getter_Copies(uiLang));
-	aUILang.Assign (uiLang);
-#endif
 
 	if (NS_FAILED (result))
 	{
@@ -416,22 +414,17 @@ mozilla_init_chrome (void)
 	result = getUILang(uiLang);
 	NS_ENSURE_SUCCESS (result, NS_ERROR_FAILURE);
 
-	return chromeRegistry->SelectLocale (NS_ConvertUCS2toUTF8(uiLang), PR_FALSE);
+	return chromeRegistry->SelectLocale (NS_ConvertUTF16toUTF8(uiLang), PR_FALSE);
 }
 
 static void
 mozilla_init_observer (MozillaEmbedSingle *single)
 {
-	EphySingle *es;
+	single->priv->mSingleObserver = new EphySingle ();
 
-	es = new EphySingle ();
-	NS_ADDREF (single->priv->mSingleObserver = es);
-
-	nsresult rv;
-	rv = es->Init (EPHY_EMBED_SINGLE (single));
-	if (NS_FAILED (rv))
+	if (single->priv->mSingleObserver)
 	{
-		g_warning ("Failed to initialised EphySingle!\n");
+		single->priv->mSingleObserver->Init (EPHY_EMBED_SINGLE (single));
 	}
 }
 
@@ -441,8 +434,8 @@ init_services (MozillaEmbedSingle *single)
 	/* Pre initialization */
 	mozilla_init_home ();
 	mozilla_init_profile ();
-	
-	/* Fire up the best */
+
+	/* Fire up the beast */
 	gtk_moz_embed_push_startup ();
 
 	/* Until gtkmozembed does this itself */
@@ -504,19 +497,6 @@ mozilla_embed_single_init (MozillaEmbedSingle *mes)
 	}
 }
 
-static void
-mozilla_embed_single_dispose (GObject *object)
-{
-	MozillaEmbedSingle *single = MOZILLA_EMBED_SINGLE (object);
-
-	if (single->priv->mSingleObserver)
-	{
-		single->priv->mSingleObserver->Detach ();
-		NS_RELEASE (single->priv->mSingleObserver);
-		single->priv->mSingleObserver = nsnull;
-	}		
-}
-
 static void
 mozilla_embed_single_finalize (GObject *object)
 {
@@ -578,11 +558,7 @@ impl_load_proxy_autoconf (EphyEmbedSingle *shell,
                 do_GetService ("@mozilla.org/network/protocol-proxy-service;1");
 	if (!pps) return;
 
-#if MOZILLA_SNAPSHOT >= 19
-	pps->ConfigureFromPAC (nsDependentCString (url));
-#else
 	pps->ConfigureFromPAC (url);
-#endif
 }
 
 static GList *
@@ -606,7 +582,7 @@ impl_get_font_list (EphyEmbedSingle *shell,
 	{
 		char *gFontString;
 
-		gFontString = g_strdup (NS_ConvertUCS2toUTF8 (fontArray[i]).get());
+		gFontString = g_strdup (NS_ConvertUTF16toUTF8 (fontArray[i]).get());
 		l = g_list_prepend (l, gFontString);
 		nsMemory::Free (fontArray[i]);
 	}
@@ -616,24 +592,6 @@ impl_get_font_list (EphyEmbedSingle *shell,
 	return g_list_reverse (l);
 }
 
-static void
-impl_print_setup (EphyEmbedSingle *single)
-{
-	nsCOMPtr<nsIPrintSettingsService> pss
-		(do_GetService ("@mozilla.org/gfx/printsettings-service;1"));
-	if (!pss) return;
-
-	nsCOMPtr<nsIPrintSettings> settings;
-	pss->GetGlobalPrintSettings (getter_AddRefs (settings));
-	if (!settings) return;
-
-	nsCOMPtr<nsIPrintingPromptService> prompt
-		(do_GetService ("@mozilla.org/embedcomp/printingprompt-service;1"));
-	if (!prompt) return;
-
-	prompt->ShowPageSetup (nsnull, settings, nsnull);
-}
-
 static GList *
 impl_list_cookies (EphyCookieManager *manager)
 {
@@ -693,6 +651,8 @@ static GList *
 impl_list_passwords (EphyPasswordManager *manager)
 {
 	GList *passwords = NULL;
+
+#ifdef HAVE_NSIPASSWORD_H
 	nsresult rv;
 
 	nsCOMPtr<nsIPasswordManager> passwordManager =
@@ -723,11 +683,12 @@ impl_list_passwords (EphyPasswordManager *manager)
 		EphyPasswordInfo *p = g_new0 (EphyPasswordInfo, 1);
 
 		p->host = g_strdup (transfer.get());
-		p->username = g_strdup(NS_ConvertUCS2toUTF8(unicodeName).get());
+		p->username = g_strdup(NS_ConvertUTF16toUTF8(unicodeName).get());
 		p->password = NULL;
 
 		passwords = g_list_prepend (passwords, p);
 	}
+#endif
 
 	return passwords;
 }
@@ -741,7 +702,7 @@ impl_remove_password (EphyPasswordManager *manager,
 	if (!pm) return;
 
 	pm->RemoveUser (nsDependentCString(info->host),
-			NS_ConvertUTF8toUCS2(nsDependentCString(info->username)));
+			NS_ConvertUTF8toUTF16(nsDependentCString(info->username)));
 }
 
 static const char *permission_type_string [] =
@@ -771,11 +732,7 @@ impl_permission_manager_add (EphyPermissionManager *manager,
 	gboolean allow = (permission == EPHY_PERMISSION_ALLOWED);
 
 	pm->Add (uri,
-#if MOZILLA_SNAPSHOT >= 10
 		 permission_type_string [type],
-#else
-		 type,
-#endif
 		 allow ? (PRUint32) nsIPermissionManager::ALLOW_ACTION :
 			 (PRUint32) nsIPermissionManager::DENY_ACTION);
 }
@@ -789,11 +746,7 @@ impl_permission_manager_remove (EphyPermissionManager *manager,
 		(do_GetService (NS_PERMISSIONMANAGER_CONTRACTID));
 	if (!pm) return;
 
-#if MOZILLA_SNAPSHOT >= 10
 	pm->Remove (nsDependentCString (host), permission_type_string [type]);
-#else
-	pm->Remove (nsDependentCString (host), type);
-#endif
 }
 
 void
@@ -821,11 +774,7 @@ impl_permission_manager_test (EphyPermissionManager *manager,
 
 	nsresult rv;
 	PRUint32 action;
-#if MOZILLA_SNAPSHOT >= 10
 	rv = pm->TestPermission (uri, permission_type_string [type], &action);
-#else
-	rv = pm->TestPermission (uri, type, &action);
-#endif
 	NS_ENSURE_SUCCESS (rv, EPHY_PERMISSION_DEFAULT);
 
 	EphyPermission permission;
@@ -869,19 +818,11 @@ impl_permission_manager_list (EphyPermissionManager *manager,
 		if (!perm) continue;
 
 		nsresult rv;
-#if MOZILLA_SNAPSHOT >= 10
 		nsCAutoString str;
 		rv = perm->GetType(str);
 		if (NS_FAILED (rv)) continue;
 
 		if (str.Equals(permission_type_string[type]))
-#else
-		PRUint32 num;
-		rv = perm->GetType(&num);
-		if (NS_FAILED (rv)) continue;
-
-		if ((PRUint32) num == (PRUint32) type)
-#endif
 		{
 			EphyPermissionInfo *info = 
 				mozilla_permission_to_ephy_permission (perm);
@@ -903,7 +844,6 @@ mozilla_embed_single_class_init (MozillaEmbedSingleClass *klass)
 
 	parent_class = (GObjectClass *) g_type_class_peek_parent (klass);
 
-	object_class->dispose = mozilla_embed_single_dispose;
 	object_class->finalize = mozilla_embed_single_finalize;
 
 	g_type_class_add_private (object_class, sizeof (MozillaEmbedSinglePrivate));
@@ -917,7 +857,6 @@ ephy_embed_single_iface_init (EphyEmbedSingleIface *iface)
 	iface->set_offline_mode = impl_set_offline_mode;
 	iface->load_proxy_autoconf = impl_load_proxy_autoconf;
 	iface->get_font_list = impl_get_font_list;
-	iface->print_setup = impl_print_setup;
 }
 
 static void
