@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-notifiers.cpp,v 1.45 2004/01/25 13:51:21 chpe Exp $
+ *  $Id: mozilla-notifiers.cpp,v 1.47 2004/05/10 22:11:25 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -268,7 +268,7 @@ mozilla_font_size_notifier (GConfClient *client,
 
 	sprintf (key, "font.%s", pref);
 
-	mozilla_prefs_set_int (key, eel_gconf_get_integer (entry->key));
+	mozilla_prefs_set_int (key, MAX (eel_gconf_get_integer (entry->key), 1));
 }
 
 static void
@@ -372,7 +372,6 @@ add_notification_and_notify (GConfClient		*client,
 			     GConfClientNotifyFunc	 func,
 			     gpointer			 user_data)
 {
-	GConfEntry *entry;
 	GError *error = NULL;
 	guint cnxn_id;
 
