@@ -16,9 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id$
+ *  $Id: print-dialog.c,v 1.27 2004/05/19 10:33:19 chpe Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "print-dialog.h"
 #include "ephy-embed-dialog.h"
 #include "ephy-file-chooser.h"
@@ -131,6 +135,8 @@ void ephy_print_dialog_response_cb		(GtkWidget *widget,
 						 EphyDialog *dialog);
 void ephy_print_dialog_browse_button_cb		(GtkWidget *widget,
 						 EphyDialog *dialog);
+void ephy_print_setup_dialog_close_button_cb	(GtkWidget *widget,
+						 EphyDialog *dialog);
 void ephy_print_setup_dialog_help_button_cb	(GtkWidget *widget,
 						 EphyDialog *dialog);
 
@@ -151,82 +157,30 @@ ephy_print_info_free (EmbedPrintInfo *info)
 	g_free (info);
 }
 
-static char *
-sanitize_filename (const char *input)
-{
-	char *dir, *filename;
-
-	if (input == NULL) return NULL;
-
-	if (g_path_is_absolute (input) == FALSE)
-	{
-		dir = eel_gconf_get_string (CONF_PRINT_DIR);
-		/* Fallback */
-		if (dir == NULL || g_path_is_absolute (dir) == FALSE)
-		{
-			g_free (dir);
-			dir = g_get_current_dir ();
-		}
-		/* Fallback */
-		if (dir == NULL)
-		{
-			dir = g_strdup (g_get_home_dir ());
-		}
-
-		filename = g_build_filename (dir, input, NULL);
-		g_free (dir);
-	}
-	else
-	{
-		filename = g_strdup (input);
-	}
-
-	dir = g_path_get_dirname (filename);
-	if (dir == NULL || g_file_test (dir, G_FILE_TEST_IS_DIR) == FALSE)
-	{
-		g_free (filename);
-		filename = NULL;
-	}
-	g_free (dir);
-
-	return filename;
-}
-
 EmbedPrintInfo *
 ephy_print_get_print_info (void)
 {
 	EmbedPrintInfo *info;
-	char *filename, *converted, *expanded, *fname = NULL;
+	char *filename;
 
 	info = g_new0 (EmbedPrintInfo, 1);
 
-	info->print_to_file = eel_gconf_get_integer (print_props[PRINTON_PROP].pref) == 1;
-
-	if (info->print_to_file)
+	filename = eel_gconf_get_string (print_props[FILE_PROP].pref);
+	if (filename != NULL)
 	{
-		filename = eel_gconf_get_string (print_props[FILE_PROP].pref);
-		if (filename != NULL)
-		{
-			converted = g_filename_from_utf8 (filename, -1, NULL, NULL, NULL);
-			if (converted != NULL)
-			{
-				expanded = gnome_vfs_expand_initial_tilde (filename);
-				fname = sanitize_filename (expanded);
-				g_free (expanded);
-				g_free (converted);
-			}
-		}
+		char *expanded;
 
-		/* fallback */
-		if (fname == NULL)
-		{
-			fname = sanitize_filename ("output.ps");
-		}
-
-		info->file = g_filename_to_utf8 (fname, -1, NULL, NULL, NULL);
-		g_free (fname);
+		expanded = gnome_vfs_expand_initial_tilde (filename);
+		info->file = g_filename_to_utf8 (expanded, -1, NULL, NULL, NULL);
+		g_free (expanded);
 	}
+	else
+	{
+		info->file = NULL;
+	}
+	g_free (filename);
 
+	info->print_to_file = eel_gconf_get_integer (print_props[PRINTON_PROP].pref) == 1;
 	info->printer = eel_gconf_get_string (print_props[PRINTER_PROP].pref);
 
 	info->pages = eel_gconf_get_integer (print_props[ALL_PAGES_PROP].pref);
@@ -254,6 +208,7 @@ ephy_print_get_print_info (void)
 	info->footer_center_string = g_strdup("");
 
 	info->frame_type = 0;
+	info->preview = FALSE;
 
 	return info;
 }
@@ -263,14 +218,39 @@ ephy_print_dialog_response_cb (GtkWidget *widget,
 			       int response,
 			       EphyDialog *dialog)
 {
+	EphyEmbed *embed;
+	EmbedPrintInfo *info;
+	gboolean only_collect_info;
+
+	only_collect_info = GPOINTER_TO_INT
+		(g_object_get_data (G_OBJECT (dialog), "only-collect-info"));
+
+	if (only_collect_info)
+	{
+		return;
+	}
+
 	switch (response)
 	{
+		case GTK_RESPONSE_OK:
+			info = ephy_print_get_print_info ();
+	
+			embed = ephy_embed_dialog_get_embed (EPHY_EMBED_DIALOG (dialog));
+			g_return_if_fail (EPHY_IS_EMBED (embed));
+	
+			ephy_embed_print (embed, info);
+	
+			ephy_print_info_free (info);
+
+			break;
 		case GTK_RESPONSE_HELP:
 			ephy_gui_help (GTK_WINDOW (widget), "epiphany", "to-print-page");
 			return;
 		default:
 			break;
 	}
+
+	g_object_unref (dialog);
 }
 
 static void
@@ -307,32 +287,47 @@ ephy_print_dialog_browse_button_cb (GtkWidget *widget,
 {
 	GtkWidget *parent;
 	EphyFileChooser *fc;
+	GtkFileFilter *filter;
 
 	parent = ephy_dialog_get_control (dialog, print_props[WINDOW_PROP].id);
 
 	fc = ephy_file_chooser_new (_("Print to"),
 				    GTK_WIDGET (parent),
 				    GTK_FILE_CHOOSER_ACTION_SAVE,
-				    CONF_PRINT_DIR);
+				    CONF_PRINT_DIR, EPHY_FILE_FILTER_NONE);
+
+	filter = ephy_file_chooser_add_mime_filter (fc, _("Postscript files"),
+					   "application/postscript", NULL);
+
+	ephy_file_chooser_add_pattern_filter (fc, _("All files"), "*", NULL);
+
+	gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (fc), filter);
 
 	g_signal_connect (GTK_DIALOG (fc), "response",
 			  G_CALLBACK (print_filechooser_response_cb),
 			  dialog);
 
-	gtk_window_set_modal (GTK_WINDOW (fc), TRUE);
 	gtk_widget_show (GTK_WIDGET (fc));
 }
 
 void
-ephy_print_setup_dialog_help_button_cb (GtkWidget *widget,
-					EphyDialog *dialog)
+ephy_print_setup_dialog_close_button_cb (GtkWidget *widget,
+					 EphyDialog *dialog)
 {
-	ephy_gui_help (GTK_WINDOW (widget), "epiphany", "using-print-setup");
+	g_object_unref (dialog);
+}
+
+void
+ephy_print_setup_dialog_help_button_cb (GtkWidget *widget,
+					 EphyDialog *dialog)
+{
+	ephy_gui_help (GTK_WINDOW (dialog), "epiphany", "using-print-setup");
 }
 
 EphyDialog *
 ephy_print_dialog_new (GtkWidget *parent,
-		       EphyEmbed *embed)
+		       EphyEmbed *embed,
+		       gboolean only_collect_info)
 {
 	EphyDialog *dialog;
 	GtkWidget *window, *button;
@@ -364,6 +359,9 @@ ephy_print_dialog_new (GtkWidget *parent,
 	button = ephy_dialog_get_control (dialog, print_props[BROWSE_PROP].id);
 	gtk_widget_set_sensitive (button, eel_gconf_key_is_writable (CONF_PRINT_FILE));
 
+	g_object_set_data (G_OBJECT (dialog), "only-collect-info",
+			   GINT_TO_POINTER (only_collect_info));
+
 	return dialog;
 }
 
