@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-toolbar-editor.c,v 1.15.2.1 2004/04/03 09:34:32 chpe Exp $
+ *  $Id: egg-toolbar-editor.c,v 1.19 2004/05/22 10:46:37 chpe Exp $
  */
 
 #include "egg-toolbar-editor.h"
@@ -268,6 +268,9 @@ egg_toolbar_editor_finalize (GObject *object)
       g_object_unref (editor->priv->model);
     }
 
+  g_list_free (editor->priv->default_actions_list);
+  g_list_free (editor->priv->actions_list);
+
   G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
@@ -407,7 +410,7 @@ set_drag_cursor (GtkWidget *widget)
   GdkCursor *cursor;
   GdkPixbuf *pixbuf;
 
-  pixbuf = gdk_pixbuf_new_from_file (CURSOR_DIR "/art/hand-open.png", NULL);
+  pixbuf = gdk_pixbuf_new_from_file (CURSOR_DIR "/hand-open.png", NULL);
   cursor = gdk_cursor_new_from_pixbuf (gdk_display_get_default (), pixbuf, 12, 12);
 
   gdk_window_set_cursor (widget->window, cursor);
@@ -416,9 +419,28 @@ set_drag_cursor (GtkWidget *widget)
 }
 
 static void
-event_box_realize_cb (GtkWidget *widget)
+event_box_realize_cb (GtkWidget *widget, GtkImage *icon)
 {
-	set_drag_cursor (widget);
+  GtkImageType type;
+
+  set_drag_cursor (widget);
+
+  type = gtk_image_get_storage_type (icon);
+  if (type == GTK_IMAGE_STOCK)
+    {
+      gchar *stock_id;
+      GdkPixbuf *pixbuf;
+      gtk_image_get_stock (icon, &stock_id, NULL);
+      pixbuf = gtk_widget_render_icon (widget, stock_id,
+	                               GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
+      gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
+      g_object_unref (pixbuf);
+    }
+  else if (type == GTK_IMAGE_PIXBUF)
+    {
+      GdkPixbuf *pixbuf = gtk_image_get_pixbuf (icon);
+      gtk_drag_source_set_icon_pixbuf (widget, pixbuf);
+    }
 }
 
 static GtkWidget *
@@ -431,7 +453,6 @@ editor_create_item (EggToolbarEditor *editor,
   GtkWidget *vbox;
   GtkWidget *label;
   gchar *label_no_mnemonic = NULL;
-  GtkImageType type;
 
   event_box = gtk_event_box_new ();
   gtk_event_box_set_visible_window (GTK_EVENT_BOX (event_box), FALSE);
@@ -444,7 +465,7 @@ editor_create_item (EggToolbarEditor *editor,
   g_signal_connect (event_box, "drag_data_delete",
 		    G_CALLBACK (editor_drag_data_delete_cb), editor);
   g_signal_connect_after (event_box, "realize",
-		          G_CALLBACK (event_box_realize_cb), NULL);
+		          G_CALLBACK (event_box_realize_cb), icon);
 
   if (action == GDK_ACTION_MOVE)
     {
@@ -454,23 +475,6 @@ editor_create_item (EggToolbarEditor *editor,
 		        G_CALLBACK (drag_end_cb), NULL);
     }
 
-  type = gtk_image_get_storage_type (icon);
-  if (type == GTK_IMAGE_STOCK)
-    {
-      gchar *stock_id;
-      GdkPixbuf *pixbuf;
-      gtk_image_get_stock (icon, &stock_id, NULL);
-      pixbuf = gtk_widget_render_icon (event_box, stock_id,
-	                               GTK_ICON_SIZE_LARGE_TOOLBAR, NULL);
-      gtk_drag_source_set_icon_pixbuf (event_box, pixbuf);
-      g_object_unref (pixbuf);
-    }
-  else if (type == GTK_IMAGE_PIXBUF)
-    {
-      GdkPixbuf *pixbuf = gtk_image_get_pixbuf (icon);
-      gtk_drag_source_set_icon_pixbuf (event_box, pixbuf);
-    }
-
   vbox = gtk_vbox_new (0, FALSE);
   gtk_widget_show (vbox);
   gtk_container_add (GTK_CONTAINER (event_box), vbox);
