@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-dialog.c,v 1.31.4.5 2004/06/29 12:39:28 chpe Exp $
+ *  $Id: ephy-dialog.c,v 1.36 2004/05/29 14:16:34 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -254,6 +254,7 @@ set_value_from_editable (PropertyInfo *info, GValue *value)
 			break;
 		default:
 			retval = FALSE;
+			g_value_unset (value);
 			g_warning ("Unsupported value type for editable %s", info->id);
 			break;
 	}
@@ -346,16 +347,17 @@ set_value_from_radiobuttongroup (PropertyInfo *info, GValue *value)
 	index = get_radio_button_active_index (info->widget);
 	g_return_val_if_fail (index >= 0, FALSE);
 
-	g_value_init (value, info->data_type);
 	if (info->data_type == G_TYPE_STRING)
 	{
 		g_return_val_if_fail (info->string_enum != NULL, FALSE);
 		g_return_val_if_fail (g_list_nth_data (info->string_enum, index) != NULL, FALSE);
 
+		g_value_init (value, G_TYPE_STRING);
 		g_value_set_string (value, (char*) g_list_nth_data (info->string_enum, index));
 	}
 	else if (info->data_type == G_TYPE_INT)
 	{
+		g_value_init (value, G_TYPE_INT);
 		g_value_set_int (value, index);
 	}
 	else
@@ -380,13 +382,14 @@ set_value_from_spin_button (PropertyInfo *info, GValue *value)
 
 	is_int = (gtk_spin_button_get_digits (GTK_SPIN_BUTTON(info->widget)) == 0);
 
-	g_value_init (value, info->data_type);
 	if (info->data_type == G_TYPE_INT && is_int)
 	{
+		g_value_init (value, G_TYPE_INT);
 		g_value_set_int (value, (int) f);
 	}
 	else if (info->data_type == G_TYPE_FLOAT)
 	{
+		g_value_init (value, G_TYPE_FLOAT);
 		g_value_set_float (value, f);
 	}
 	else
@@ -408,9 +411,9 @@ set_value_from_togglebutton (PropertyInfo *info, GValue *value)
 
 	active = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (info->widget));
 
-	g_value_init (value, info->data_type);
 	if (info->data_type == G_TYPE_BOOLEAN)
 	{
+		g_value_init (value, info->data_type);
 		g_value_set_boolean (value, active);
 	}
 	else
@@ -585,6 +588,7 @@ set_combo_box_from_value (PropertyInfo *info, const  GValue *value)
 		else
 		{
 			char *v;
+
 			gtk_combo_box_set_active (GTK_COMBO_BOX (info->widget), -1);
 
 			v = g_strdup_value_contents (value);
@@ -752,16 +756,12 @@ set_pref_from_info_and_emit (PropertyInfo *info)
 static void
 togglebutton_clicked_cb (GtkWidget *widget, PropertyInfo *info)
 {
-	info->sane_state = TRUE;
-
 	set_pref_from_info_and_emit (info);
 }
 
 static void
 radiobutton_clicked_cb (GtkWidget *widget, PropertyInfo *info)
 {
-	info->sane_state = TRUE;
-
 	if (!gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON(widget)))
 	{
 		return;
@@ -796,8 +796,6 @@ spinbutton_timeout_cb (PropertyInfo *info)
 		 * and set in the pref. Otherwise the old value is used */
 		gtk_spin_button_update (GTK_SPIN_BUTTON (info->widget));
 
-		info->sane_state = TRUE;
-
 		set_pref_from_info_and_emit (info);
 
 		/* done, don't run again */
@@ -834,8 +832,6 @@ spinbutton_changed_cb (GtkWidget *widget, PropertyInfo *info)
 static void
 changed_cb (GtkWidget *widget, PropertyInfo *info)
 {
-	info->sane_state = TRUE;
-
 	set_pref_from_info_and_emit (info);
 }
 
