@@ -21,8 +21,14 @@
 
    Author: John Sullivan <sullivan@eazel.com>,
 	   Marco Pesenti Gritti <marco@it.gnome.org> Markup support
+
+  $Id: ephy-ellipsizing-label.c,v 1.3 2004/03/17 09:02:37 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-ellipsizing-label.h"
 
 #include <string.h>
