@@ -15,9 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-favicon-action.c,v 1.23 2003/11/07 23:00:02 chpe Exp $
+ *  $Id: ephy-favicon-action.c,v 1.25 2004/03/17 09:08:06 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-favicon-action.h"
 #include "ephy-window.h"
 #include "ephy-tab.h"
@@ -214,8 +218,7 @@ ephy_favicon_action_set_property (GObject *object,
 			break;
 		case PROP_ICON:
 			g_free (fav->priv->icon);
-			fav->priv->icon = g_strdup (g_value_get_string (value));
-			g_object_notify(object, "icon");
+			fav->priv->icon = g_value_dup_string (value);
 			break;
 	}
 }
@@ -236,7 +239,7 @@ ephy_favicon_action_get_property (GObject *object,
 			g_value_set_object (value, fav->priv->window);
 			break;
 		case PROP_ICON:
-			g_value_set_object (value, fav->priv->icon);
+			g_value_set_string (value, fav->priv->icon);
 			break;
 	}
 }
