@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-shell.c,v 1.84.4.3 2004/09/07 21:23:57 chpe Exp $
+ *  $Id: ephy-shell.c,v 1.85 2004/03/29 18:48:38 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -53,12 +53,6 @@
 #include <unistd.h>
 #include <libgnomeui/gnome-client.h>
 
-#ifdef ENABLE_NAUTILUS_VIEW
-#include <bonobo/bonobo-generic-factory.h>
-#include "ephy-nautilus-view.h"
-#endif
-
-#define EPHY_NAUTILUS_VIEW_IID "OAFIID:GNOME_Epiphany_NautilusView"
 #define AUTOMATION_IID "OAFIID:GNOME_Epiphany_Automation"
 #define SERVER_TIMEOUT 60000
 
@@ -76,6 +70,7 @@ struct EphyShellPrivate
 	GtkWidget *history_window;
 	GObject *pdm_dialog;
 	GObject *prefs_dialog;
+	GObject *print_setup_dialog;
 	GList *del_on_exit;
 	guint server_timeout;
 };
@@ -150,12 +145,6 @@ ephy_automation_factory_cb (BonoboGenericFactory *this_factory,
 	{
 		return BONOBO_OBJECT (g_object_new (EPHY_TYPE_AUTOMATION, NULL));
 	}
-#ifdef ENABLE_NAUTILUS_VIEW
-	else if (strcmp (iid, EPHY_NAUTILUS_VIEW_IID) == 0)
-	{
-		return BONOBO_OBJECT (ephy_nautilus_view_new_component (shell));
-	}
-#endif
 
 	g_assert_not_reached ();
 
@@ -191,6 +180,7 @@ ephy_shell_init (EphyShell *shell)
 	shell->priv->bme = NULL;
 	shell->priv->history_window = NULL;
 	shell->priv->pdm_dialog = NULL;
+	shell->priv->print_setup_dialog = NULL;
 	shell->priv->toolbars_model = NULL;
 	shell->priv->fs_toolbars_model = NULL;
 	shell->priv->extensions_manager = NULL;
@@ -271,7 +261,7 @@ save_yourself_cb (GnomeClient *client,
 		  EphyShell *shell)
 {
 	char *argv[] = { "epiphany", "--load-session", NULL };
-	char *discard_argv[] = { "rm", "-f", NULL };
+	char *discard_argv[] = { "rm", "-r", NULL };
 	EphySession *session;
 	char *tmp, *save_to;
 
@@ -481,6 +471,12 @@ ephy_shell_finalize (GObject *object)
 		g_object_unref (shell->priv->prefs_dialog);
 	}
 
+	LOG ("Unref print setup dialog")
+	if (shell->priv->print_setup_dialog)
+	{
+		g_object_unref (shell->priv->print_setup_dialog);
+	}
+
 	LOG ("Unref bookmarks")
 	if (shell->priv->bookmarks)
 	{
@@ -580,11 +576,11 @@ ephy_shell_new_tab (EphyShell *shell,
 		    flags & EPHY_NEW_TAB_APPEND_GROUPED)) &&
 		  !(flags & EPHY_NEW_TAB_APPEND_LAST);
 
-	if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_tab != NULL)
+	if ((flags & EPHY_NEW_TAB_APPEND_AFTER) && previous_embed != NULL)
 	{
 		nb = ephy_window_get_notebook (window);
 		position = gtk_notebook_page_num (GTK_NOTEBOOK (nb),
-						  GTK_WIDGET (previous_tab)) + 1;
+						  GTK_WIDGET (previous_embed)) + 1;
 	}
 	else
 	{
@@ -806,3 +802,17 @@ ephy_shell_get_prefs_dialog (EphyShell *shell)
 
 	return shell->priv->prefs_dialog;
 }
+
+GObject *
+ephy_shell_get_print_setup_dialog (EphyShell *shell)
+{
+	if (shell->priv->print_setup_dialog == NULL)
+	{
+		shell->priv->print_setup_dialog = G_OBJECT (ephy_print_setup_dialog_new ());
+
+		g_object_add_weak_pointer (shell->priv->print_setup_dialog,
+					   (gpointer *) &shell->priv->print_setup_dialog);
+	}
+
+	return shell->priv->print_setup_dialog;
+}
