@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab.c,v 1.95.4.1 2004/03/22 09:21:30 marco Exp $
+ *  $Id: ephy-tab.c,v 1.105 2004/05/20 22:43:09 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -64,7 +64,6 @@
 
 struct EphyTabPrivate
 {
-	EphyWindow *window;
 	char *status_message;
 	char *link_message;
 	char *icon_address;
@@ -101,7 +100,6 @@ enum
 	PROP_SECURITY,
 	PROP_TITLE,
 	PROP_VISIBLE,
-	PROP_WINDOW,
 	PROP_ZOOM
 };
 
@@ -173,9 +171,6 @@ ephy_tab_set_property (GObject *object,
 			ephy_tab_set_location (tab, g_value_get_string (value),
 					       TAB_ADDRESS_EXPIRE_NOW);
 			break;
-		case PROP_WINDOW:
-			ephy_tab_set_window (tab, g_value_get_object (value));
-			break;
 		case PROP_ICON:
 		case PROP_LOAD_PROGRESS:
 		case PROP_LOAD_STATUS:
@@ -227,9 +222,6 @@ ephy_tab_get_property (GObject *object,
 		case PROP_VISIBLE:
 			g_value_set_boolean (value, tab->priv->visibility);
 			break;
-		case PROP_WINDOW:
-			g_value_set_object (value, tab->priv->window);
-			break;
 		case PROP_ZOOM:
 			g_value_set_float (value, tab->priv->zoom);
 			break;
@@ -252,33 +244,31 @@ ephy_tab_size_allocate (GtkWidget *widget,
 	}
 }
 
-static void
-ephy_tab_parent_set (GtkWidget *widget,
-		     GtkWidget *previous_parent)
+static EphyWindow *
+ephy_tab_get_window (EphyTab *tab)
 {
-	if (widget->parent)
-	{
-		GtkWidget *toplevel;
-		toplevel = gtk_widget_get_toplevel (widget);
+	GtkWidget *toplevel;
 
-		ephy_tab_set_window (EPHY_TAB (widget), EPHY_WINDOW (toplevel));
-	}
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (tab));
+	g_return_val_if_fail (toplevel != NULL, NULL);
 
-	if (GTK_WIDGET_CLASS (parent_class)->parent_set)
-	{
-		GTK_WIDGET_CLASS (parent_class)->parent_set (widget, previous_parent);
-	}
+	return EPHY_WINDOW (toplevel);
 }
 
 static void
 ephy_tab_action_activate_cb (GtkAction *action, EphyTab *tab)
 {
+	EphyWindow *window;
+
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
+	window = ephy_tab_get_window (tab);
+	g_return_if_fail (window != NULL);
+
 	if (gtk_toggle_action_get_active (GTK_TOGGLE_ACTION (action)) &&
-	    ephy_window_get_active_tab (tab->priv->window) != tab)
+	    ephy_window_get_active_tab (window) != tab)
 	{
-		ephy_window_jump_to_tab (tab->priv->window, tab);
+		ephy_window_jump_to_tab (window, tab);
 	}
 }
 
@@ -295,7 +285,6 @@ ephy_tab_class_init (EphyTabClass *class)
 	object_class->set_property = ephy_tab_set_property;
 
 	widget_class->size_allocate = ephy_tab_size_allocate;
-	widget_class->parent_set = ephy_tab_parent_set;
 	
 	g_object_class_install_property (object_class,
 					 PROP_ADDRESS,
@@ -318,7 +307,7 @@ ephy_tab_class_init (EphyTabClass *class)
 					 g_param_spec_int ("load-progress",
 							   "Load progress",
 							   "The tab's load progress in percent",
-							   -1,
+							   0,
 							   100,
 							   0,
 							   G_PARAM_READABLE));
@@ -377,14 +366,6 @@ ephy_tab_class_init (EphyTabClass *class)
 							       TRUE,
 							       G_PARAM_READABLE));
 
-	g_object_class_install_property (object_class,
-					 PROP_WINDOW,
-					 g_param_spec_object ("window",
-							      "Window",
-							      "The tab's parent window",
-							      EPHY_TYPE_WINDOW,
-							      G_PARAM_READWRITE));
-
 	g_object_class_install_property (object_class,
 					 PROP_ZOOM,
 					 g_param_spec_float ("zoom",
@@ -441,6 +422,14 @@ address_has_web_scheme (const char *address)
 
 /* Public functions */
 
+/**
+ * ephy_tab_new:
+ *
+ * Equivalent to g_object_new(), but returns an #EphyTab so you don't have to
+ * cast it.
+ *
+ * Returns: a new #EphyTab
+ **/
 EphyTab *
 ephy_tab_new (void)
 {
@@ -457,6 +446,16 @@ ephy_tab_set_load_status (EphyTab *tab, gboolean status)
 	g_object_notify (G_OBJECT (tab), "load-status");
 }
 
+/**
+ * ephy_tab_get_load_status:
+ * @tab: an #EphyTab
+ *
+ * Returns whether the web page in @tab has finished loading. A web page is
+ * only finished loading after all images, styles, and other dependencies have
+ * been downloaded and rendered.
+ *
+ * Return value: %TRUE if the page is still loading, %FALSE if complete
+ **/
 gboolean
 ephy_tab_get_load_status (EphyTab *tab)
 {
@@ -476,6 +475,21 @@ ephy_tab_set_link_message (EphyTab *tab, char *message)
 	g_object_notify (G_OBJECT (tab), "message");
 }
 
+/**
+ * ephy_tab_get_link_message:
+ * @tab: an #EphyTab
+ *
+ * Returns the message displayed in @tab's #EphyWindow's #EphyStatusbar when
+ * the user hovers the mouse over a hyperlink.
+ *
+ * The message returned has a limited lifetime, and so should be copied with
+ * g_strdup() if it must be stored.
+ *
+ * Listen to the "link_message" signal on the @tab's #EphyEmbed to be notified
+ * when the link message changes.
+ *
+ * Return value: The current link statusbar message
+ **/
 const char *
 ephy_tab_get_link_message (EphyTab *tab)
 {
@@ -484,6 +498,14 @@ ephy_tab_get_link_message (EphyTab *tab)
 	return tab->priv->link_message;
 }
 
+/**
+ * ephy_tab_get_embed:
+ * @tab: an #EphyTab
+ *
+ * Returns @tab's #EphyEmbed.
+ *
+ * Return value: @tab's #EphyEmbed
+ **/
 EphyEmbed *
 ephy_tab_get_embed (EphyTab *tab)
 {
@@ -492,6 +514,14 @@ ephy_tab_get_embed (EphyTab *tab)
 	return EPHY_EMBED (gtk_bin_get_child (GTK_BIN (tab)));
 }
 
+/**
+ * ephy_tab_for_embed
+ * @embed: an #EphyEmbed
+ *
+ * Returns the #EphyTab which holds @embed.
+ *
+ * Return value: the #EphyTab which holds @embed
+ **/
 EphyTab *
 ephy_tab_for_embed (EphyEmbed *embed)
 {
@@ -505,37 +535,38 @@ ephy_tab_for_embed (EphyEmbed *embed)
 	return EPHY_TAB (parent);
 }
 
-void
-ephy_tab_set_window (EphyTab *tab, EphyWindow *window)
-{
-	g_return_if_fail (EPHY_IS_TAB (tab));
-	if (window) g_return_if_fail (EPHY_IS_WINDOW (window));
-
-	if (window != tab->priv->window)
-	{
-		tab->priv->window = window;
-
-		g_object_notify (G_OBJECT (tab), "window");
-	}
-}
-
-EphyWindow *
-ephy_tab_get_window (EphyTab *tab)
-{
-	g_return_val_if_fail (EPHY_IS_TAB (tab), NULL);
-
-	return tab->priv->window;
-}
-
+/**
+ * ephy_tab_get_size:
+ * @tab: an #EphyTab
+ * @width: return location for width, or %NULL
+ * @height: return location for height, or %NULL
+ *
+ * Obtains the size of @tab. This is not guaranteed to be the actual number of
+ * pixels occupied by the #EphyTab.
+ **/
 void
 ephy_tab_get_size (EphyTab *tab, int *width, int *height)
 {
 	g_return_if_fail (EPHY_IS_TAB (tab));
 
-	*width = tab->priv->width;
-	*height = tab->priv->height;
+	if (width != NULL)
+	{
+		*width = tab->priv->width;
+	}
+	if (height != NULL)
+	{
+		*height = tab->priv->height;
+	}
 }
 
+/**
+ * ephy_tab_get_visibility:
+ * @tab: an #EphyTab
+ *
+ * FIXME: Nobody really knows what this does. Someone must investigate.
+ *
+ * Return value; %TRUE if @tab's "visibility" property is set
+ **/
 gboolean
 ephy_tab_get_visibility (EphyTab *tab)
 {
@@ -544,17 +575,6 @@ ephy_tab_get_visibility (EphyTab *tab)
 	return tab->priv->visibility;
 }
 
-void
-ephy_tab_set_visibility (EphyTab *tab,
-                         gboolean visible)
-{
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	tab->priv->visibility = visible;
-
-	g_object_notify (G_OBJECT (tab), "visible");
-}
-
 static void
 ephy_tab_icon_cache_changed_cb (EphyFaviconCache *cache,
 				const char *address,
@@ -597,6 +617,14 @@ ephy_tab_set_icon_address (EphyTab *tab, const char *address)
 	g_object_notify (G_OBJECT (tab), "icon");
 }
 
+/**
+ * ephy_tab_get_icon_address:
+ * @tab: an #EphyTab
+ *
+ * Returns a URL which points to @tab's favicon.
+ *
+ * Return value: a URL to @tab's favicon
+ **/
 const char *
 ephy_tab_get_icon_address (EphyTab *tab)
 {
@@ -668,11 +696,11 @@ ephy_tab_address_cb (EphyEmbed *embed, const char *address, EphyTab *tab)
 			g_value_unset (&value);
 		}
 
-		current_zoom = ephy_embed_zoom_get (embed);
+		current_zoom = ephy_embed_get_zoom (embed);
 		if (zoom != current_zoom)
 		{
 			tab->priv->setting_zoom = TRUE;
-			ephy_embed_zoom_set (embed, zoom, FALSE);
+			ephy_embed_set_zoom (embed, zoom, FALSE);
 			tab->priv->setting_zoom = FALSE;
 		}
 	}
@@ -706,7 +734,7 @@ ephy_tab_zoom_changed_cb (EphyEmbed *embed, float zoom, EphyTab *tab)
 		{
 			float zoom;
 
-			zoom = ephy_embed_zoom_get (embed);
+			zoom = ephy_embed_get_zoom (embed);
 
 			g_value_init (&value, G_TYPE_FLOAT);
 			g_value_set_float (&value, zoom);
@@ -734,7 +762,7 @@ ephy_tab_title_cb (EphyEmbed *embed, EphyTab *tab)
 static int
 build_load_percent (int requests_done, int requests_total)
 {
-	int percent;
+	int percent= 0;
 
 	if (requests_total > 0)
 	{
@@ -744,10 +772,6 @@ build_load_percent (int requests_done, int requests_total)
 		   total requests. Their progress widget clamp the value */
 		percent = CLAMP (percent, 0, 100);
 	}
-	else
-	{
-		percent = -1;
-	}
 
 	return percent;
 }
@@ -891,7 +915,7 @@ ephy_tab_net_state_cb (EphyEmbed *embed, const char *uri,
 		}
 		else if (state & EMBED_STATE_STOP)
 		{
-			ephy_tab_set_load_percent (tab, 0);
+			ephy_tab_set_load_percent (tab, 100);
 			ephy_tab_set_load_status (tab, FALSE);
 			ephy_tab_update_navigation_flags (tab, embed);
 			tab->priv->address_expire = TAB_ADDRESS_EXPIRE_NOW;
@@ -908,6 +932,9 @@ ephy_tab_new_window_cb (EphyEmbed *embed, EphyEmbed **new_embed,
 	EphyTab *new_tab;
 	EphyWindow *window;
 
+	LOG ("ephy_tab_new_window_cb tab %p with parent %p chrome %d",
+	     tab, ((GtkWidget *) tab)->parent, chromemask)
+
 	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_JAVASCRIPT_CHROME))
 	{
 		window = ephy_window_new ();
@@ -937,6 +964,9 @@ static void
 ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 			EphyTab *tab)
 {
+	LOG ("ephy_tab_visibility_cb tab %p visibility %d",
+	     tab, visibility)
+
 	if (visibility)
 	{
 		gtk_widget_show (GTK_WIDGET (tab));
@@ -946,20 +976,28 @@ ephy_tab_visibility_cb (EphyEmbed *embed, gboolean visibility,
 		gtk_widget_hide (GTK_WIDGET (tab));
 	}
 
-	ephy_tab_set_visibility (tab, visibility);
+	tab->priv->visibility = visibility;
+
+	g_object_notify (G_OBJECT (tab), "visible");
 }
 
 static void
 ephy_tab_destroy_brsr_cb (EphyEmbed *embed, EphyTab *tab)
 {
+	EphyWindow *window;
 	GtkWidget *notebook;
 
 	g_return_if_fail (EPHY_IS_TAB (tab));
-	g_return_if_fail (tab->priv->window != NULL);
+
+	LOG ("ephy_tab_destroy_browser_cb tab %p parent %p",
+	     tab, ((GtkWidget *) tab)->parent)
+
+	window = ephy_tab_get_window (tab);
+	g_return_if_fail (window != NULL);
 
 	/* Do not use ephy_window_remove_tab because it will
 	   check for unsubmitted forms */
-	notebook = ephy_window_get_notebook (tab->priv->window);
+	notebook = ephy_window_get_notebook (window);
 	ephy_notebook_remove_tab (EPHY_NOTEBOOK (notebook), tab);
 }
 
@@ -970,10 +1008,12 @@ ephy_tab_size_to_cb (EphyEmbed *embed, gint width, gint height,
 	GtkWidget *notebook;
 	EphyWindow *window;
 
+	LOG ("ephy_tab_size_to_cb tab %p width %d height %d", tab, width, height)
+
 	tab->priv->width = width;
 	tab->priv->height = height;
 
-	window = tab->priv->window;
+	window = ephy_tab_get_window (tab);
 	notebook = ephy_window_get_notebook (window);
 
 	/* Do not resize window with multiple tabs.
@@ -1072,7 +1112,6 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 {
 	EphyEmbedEventType type;
 	EmbedEventContext context;
-	EphyWindow *window;
 	guint modifier;
 	gboolean handled = TRUE;
 	gboolean with_control, with_shift, is_left_click, is_middle_click;
@@ -1082,9 +1121,6 @@ ephy_tab_dom_mouse_click_cb (EphyEmbed *embed,
 
 	g_return_val_if_fail (EPHY_IS_EMBED_EVENT(event), FALSE);
 
-	window = ephy_tab_get_window (tab);
-	g_return_val_if_fail (window != NULL, FALSE);
-
 	type = ephy_embed_event_get_event_type (event);
 	context = ephy_embed_event_get_context (event);
 	modifier = ephy_embed_event_get_modifier (event);
@@ -1177,7 +1213,6 @@ ephy_tab_init (EphyTab *tab)
 
 	tab->priv = EPHY_TAB_GET_PRIVATE (tab);
 
-	tab->priv->window = NULL;
 	tab->priv->status_message = NULL;
 	tab->priv->link_message = NULL;
 	tab->priv->total_requests = 0;
@@ -1257,6 +1292,13 @@ ephy_tab_init (EphyTab *tab)
 				 tab,  0);
 }
 
+/**
+ * ephy_tab_set_load_percent:
+ * @tab: an #EphyTab
+ * @percent: a percentage, from 0 to 100.
+ *
+ * Sets the load percentage. This will be displayed in the progressbar.
+ **/
 void
 ephy_tab_set_load_percent (EphyTab *tab, int percent)
 {
@@ -1270,10 +1312,18 @@ ephy_tab_set_load_percent (EphyTab *tab, int percent)
 	}
 }
 
+/**
+ * ephy_tab_get_load_percent:
+ * @tab: an #EphyTab
+ *
+ * Returns the page load percentage (displayed in the progressbar).
+ *
+ * Return value: a percentage from 0 to 100.
+ **/
 int
 ephy_tab_get_load_percent (EphyTab *tab)
 {
-	g_return_val_if_fail (EPHY_IS_TAB (tab), -1);
+	g_return_val_if_fail (EPHY_IS_TAB (tab), 0);
 
 	return tab->priv->load_percent;
 }
@@ -1306,6 +1356,14 @@ ephy_tab_update_navigation_flags (EphyTab *tab, EphyEmbed *embed)
 	}
 }
 
+/**
+ * ephy_tab_get_navigation_flags:
+ * @tab: an #EphyTab
+ *
+ * Returns @tab's navigation flags.
+ *
+ * Return value: @tab's navigation flags
+ **/
 TabNavigationFlags
 ephy_tab_get_navigation_flags (EphyTab *tab)
 {
@@ -1314,6 +1372,22 @@ ephy_tab_get_navigation_flags (EphyTab *tab)
 	return tab->priv->nav_flags;
 }
 
+/**
+ * ephy_tab_get_status_message:
+ * @tab: an #EphyTab
+ *
+ * Returns the message displayed in @tab's #EphyWindow's #EphyStatusbar. If the
+ * user is hovering the mouse over a hyperlink, this function will return the
+ * same value as ephy_tab_get_link_message(). Otherwise, it will return a
+ * network status message, or NULL.
+ *
+ * The message returned has a limited lifetime, and so should be copied with
+ * g_strdup() if it must be stored.
+ *
+ * Listen to "notify::message" to be notified when the message property changes.
+ *
+ * Return value: The current statusbar message
+ **/
 const char *
 ephy_tab_get_status_message (EphyTab *tab)
 {
@@ -1390,7 +1464,7 @@ ephy_tab_set_title (EphyTab *tab, EphyEmbed *embed, const char *new_title)
 	title_short = ephy_string_shorten (title, MAX_LABEL_LENGTH);
 	title_tmp = ephy_string_double_underscores (title_short);
 
-	/**
+	/*
 	 * FIXME: instead of shortening the title here, use an egg action
 	 * which creates menu items with ellipsizing labels
 	 */
@@ -1404,6 +1478,14 @@ ephy_tab_set_title (EphyTab *tab, EphyEmbed *embed, const char *new_title)
 	g_object_notify (G_OBJECT (tab), "title");
 }
 
+/**
+ * ephy_tab_get_title:
+ * @tab: an #EphyTab
+ *
+ * Returns the title of the web page loaded in @tab.
+ *
+ * Return value: @tab's loaded web page's title
+ **/
 const char *
 ephy_tab_get_title (EphyTab *tab)
 {
@@ -1412,6 +1494,20 @@ ephy_tab_get_title (EphyTab *tab)
 	return tab->priv->title;
 }
 
+/**
+ * ephy_tab_get_location:
+ * @tab: an #EphyTab
+ *
+ * Returns the text that @tab's #EphyWindow will display in its location toolbar
+ * entry when @tab is selected.
+ *
+ * This is not guaranteed to be the same as @tab's #EphyEmbed's location,
+ * available through ephy_embed_get_location(). As the user types a new address
+ * into the location entry, ephy_tab_get_location()'s returned string will
+ * change.
+ *
+ * Return value: @tab's #EphyWindow's location entry when @tab is selected
+ **/
 const char *
 ephy_tab_get_location (EphyTab *tab)
 {
@@ -1420,6 +1516,14 @@ ephy_tab_get_location (EphyTab *tab)
 	return tab->priv->address;
 }
 
+/**
+ * ephy_tab_set_location:
+ * @tab: an #EphyTab
+ * @address: a string (ideally a URL)
+ * @expire: beats me
+ *
+ * DO NOT USE
+ */
 void
 ephy_tab_set_location (EphyTab *tab,
 		       const char *address,
@@ -1453,6 +1557,14 @@ ephy_tab_set_security_level (EphyTab *tab, EmbedSecurityLevel level)
 	g_object_notify (G_OBJECT (tab), "security-level");
 }
 
+/**
+ * ephy_tab_get_security_level:
+ * @tab: an #EphyTab
+ *
+ * Returns the security level of the webpage loaded in @tab.
+ *
+ * Return value: @tab's loaded page's security level
+ **/
 EmbedSecurityLevel
 ephy_tab_get_security_level (EphyTab *tab)
 {
@@ -1471,6 +1583,15 @@ ephy_tab_set_zoom (EphyTab *tab, float zoom)
 	g_object_notify (G_OBJECT (tab), "zoom");
 }
 
+/**
+ * ephy_tab_get_zoom:
+ * @tab: an #EphyTab
+ *
+ * Returns the zoom level of the web page loaded in @tab. A return value of
+ * 1.0 corresponds to 100% zoom (normal size).
+ *
+ * Return value: @tab's loaded page's zoom level
+ **/
 float
 ephy_tab_get_zoom (EphyTab *tab)
 {
@@ -1479,6 +1600,18 @@ ephy_tab_get_zoom (EphyTab *tab)
 	return tab->priv->zoom;
 }
 
+/**
+ * ephy_tab_get_action:
+ * @tab: an #EphyTab
+ *
+ * DO NOT USE
+ *
+ * Returns the #GtkToggleAction represented by the labelled tab displayed at the
+ * top of @tab's #EphyWindow when multiple tabs are loaded. Activating this
+ * action will switch the window to display @tab.
+ *
+ * Return value: @tab's #GtkToggleAction
+ **/
 GObject *
 ephy_tab_get_action (EphyTab *tab)
 {
