@@ -15,20 +15,26 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.17.2.1 2003/11/10 01:40:52 chpe Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.25 2004/03/17 09:08:06 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-toolbars-model.h"
 #include "ephy-dnd.h"
 #include "ephy-bookmarks.h"
 #include "ephy-node-common.h"
 #include "ephy-file-helpers.h"
+#include "ephy-history.h"
+#include "ephy-embed-shell.h"
 #include "ephy-shell.h"
 #include "ephy-debug.h"
 #include "ephy-string.h"
 
 #include <string.h>
-#include <bonobo/bonobo-i18n.h>
+#include <glib/gi18n.h>
 
 static void ephy_toolbars_model_class_init (EphyToolbarsModelClass *klass);
 static void ephy_toolbars_model_init       (EphyToolbarsModel *t);
@@ -56,6 +62,8 @@ enum
 
 static GObjectClass *parent_class = NULL;
 
+#define EPHY_TOOLBARS_MODEL_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_TOOLBARS_MODEL, EphyToolbarsModelPrivate))
+
 struct EphyToolbarsModelPrivate
 {
 	EphyBookmarks *bookmarks;
@@ -66,9 +74,9 @@ struct EphyToolbarsModelPrivate
 GType
 ephy_toolbars_model_get_type (void)
 {
-	static GType ephy_toolbars_model_type = 0;
+	static GType type = 0;
 
-	if (ephy_toolbars_model_type == 0)
+	if (type == 0)
 	{
 		static const GTypeInfo our_info = {
 		sizeof (EphyToolbarsModelClass),
@@ -82,12 +90,12 @@ ephy_toolbars_model_get_type (void)
 		(GInstanceInitFunc) ephy_toolbars_model_init
 	};
 
-	ephy_toolbars_model_type = g_type_register_static (EGG_TOOLBARS_MODEL_TYPE,
-							   "EphyToolbarsModel",
-							   &our_info, 0);
+	type = g_type_register_static (EGG_TYPE_TOOLBARS_MODEL,
+				       "EphyToolbarsModel",
+				       &our_info, 0);
 	}
 
-	return ephy_toolbars_model_type;
+	return type;
 }
 
 char *
@@ -198,20 +206,22 @@ impl_get_item_id (EggToolbarsModel *t,
 			}
 
 			node = ephy_bookmarks_add (bookmarks, title, netscape_url[URL]);
-			g_return_val_if_fail (node != NULL, NULL);
 
-			gh = ephy_embed_shell_get_global_history (EPHY_EMBED_SHELL (ephy_shell));
-			icon = ephy_history_get_icon (gh, netscape_url[URL]);
-
-			if (icon)
+			if (node != NULL)
 			{
-				ephy_bookmarks_set_icon (bookmarks, netscape_url[URL], icon);
+				gh = EPHY_HISTORY (ephy_embed_shell_get_global_history (embed_shell));
+				icon = ephy_history_get_icon (gh, netscape_url[URL]);
+
+				if (icon)
+				{
+					ephy_bookmarks_set_icon (bookmarks, netscape_url[URL], icon);
+				}
 			}
 		}
 
 		g_strfreev (netscape_url);
 
-		g_return_val_if_fail (node != NULL, NULL);
+		if (node == NULL) return NULL;
 
 		return ephy_toolbars_model_get_action_name
 			(model, ephy_node_get_id (node));
@@ -275,6 +285,30 @@ get_toolbar_and_item_pos (EphyToolbarsModel *model,
 	return FALSE;
 }
 
+static int
+get_toolbar_pos (EphyToolbarsModel *model,
+		 const char *name)
+{
+	int i, n_toolbars;
+
+	n_toolbars = egg_toolbars_model_n_toolbars
+		(EGG_TOOLBARS_MODEL (model));
+
+	for (i = 0; i < n_toolbars; i++)
+	{
+		const char *t_name;
+
+		t_name = egg_toolbars_model_toolbar_nth
+			(EGG_TOOLBARS_MODEL (model), i);
+		if (strcmp (name, t_name) == 0)
+		{
+			return i;
+		}
+	}
+
+	return -1;
+}
+
 static gboolean
 impl_add_item (EggToolbarsModel    *t,
 	       int		    toolbar_position,
@@ -317,14 +351,41 @@ connect_item (EphyToolbarsModel *model,
 	}
 }
 
+static void
+update_toolbar_removeable_flag (EggToolbarsModel *model)
+{
+	int i, n_toolbars;
+	int flag = 0;
+
+	n_toolbars = egg_toolbars_model_n_toolbars (model);
+
+	/* If there is only one toolbar and the bookmarks bar */
+	if (n_toolbars <= 2)
+	{
+		flag = EGG_TB_MODEL_NOT_REMOVABLE;
+	}
+
+	for (i = 0; i < n_toolbars; i++)
+	{
+		const char *t_name;
+
+		t_name = egg_toolbars_model_toolbar_nth (model, i);
+		g_return_if_fail (t_name != NULL);
+
+		if (!(strcmp (t_name, "BookmarksBar") == 0))
+		{
+			egg_toolbars_model_set_flags (model, flag, i);
+		}
+	}
+}
+
 static void
 ephy_toolbars_model_set_bookmarks (EphyToolbarsModel *model, EphyBookmarks *bookmarks)
 {
 	EggToolbarsModel *egg_model = EGG_TOOLBARS_MODEL (model);
 	gboolean success = FALSE;
 
-	model->priv->bookmarks = bookmarks;
-	g_object_ref (model->priv->bookmarks);
+	model->priv->bookmarks = g_object_ref (bookmarks);
 
 	model->priv->loading = TRUE;
 
@@ -342,6 +403,13 @@ ephy_toolbars_model_set_bookmarks (EphyToolbarsModel *model, EphyBookmarks *book
 		egg_toolbars_model_load (egg_model, default_xml);
 	}
 
+	/* ensure that we have a BookmarksBar */
+	if (get_toolbar_pos (model, "BookmarksBar") == -1)
+	{
+		egg_toolbars_model_add_toolbar
+			(EGG_TOOLBARS_MODEL (model), -1, "BookmarksBar");
+	}
+
 	model->priv->loading = FALSE;
 }
 
@@ -405,8 +473,10 @@ ephy_toolbars_model_class_init (EphyToolbarsModelClass *klass)
                                          g_param_spec_object ("bookmarks",
                                                               "Bookmarks",
                                                               "Bookmarks",
-                                                              EPHY_BOOKMARKS_TYPE,
+                                                              EPHY_TYPE_BOOKMARKS,
                                                               G_PARAM_READWRITE));
+
+	g_type_class_add_private (object_class, sizeof(EphyToolbarsModelPrivate));
 }
 
 static void
@@ -447,18 +517,21 @@ static void
 toolbar_added (EphyToolbarsModel *model, int position)
 {
 	save_changes (model);
+	update_toolbar_removeable_flag (EGG_TOOLBARS_MODEL (model));
 }
 
 static void
 toolbar_removed (EphyToolbarsModel *model, int position)
 {
 	save_changes (model);
+	update_toolbar_removeable_flag (EGG_TOOLBARS_MODEL (model));
 }
 
 static void
 ephy_toolbars_model_init (EphyToolbarsModel *t)
 {
-	t->priv = g_new0 (EphyToolbarsModelPrivate, 1);
+	t->priv = EPHY_TOOLBARS_MODEL_GET_PRIVATE (t);
+
 	t->priv->bookmarks = NULL;
 	t->priv->loading = FALSE;
 	t->priv->xml_file = g_build_filename (ephy_dot_dir (),
@@ -476,56 +549,21 @@ ephy_toolbars_model_finalize (GObject *object)
 {
 	EphyToolbarsModel *t = EPHY_TOOLBARS_MODEL (object);
 
-	g_return_if_fail (object != NULL);
-	g_return_if_fail (IS_EPHY_TOOLBARS_MODEL (object));
-
 	save_changes (t);
 
 	g_object_unref (t->priv->bookmarks);
 
 	g_free (t->priv->xml_file);
 
-	g_free (t->priv);
-
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
 EphyToolbarsModel *
 ephy_toolbars_model_new (EphyBookmarks *bookmarks)
 {
-	EphyToolbarsModel *t;
-
-	t = EPHY_TOOLBARS_MODEL (g_object_new (EPHY_TOOLBARS_MODEL_TYPE,
-					       "bookmarks", bookmarks,
-					       NULL));
-
-	g_return_val_if_fail (t->priv != NULL, NULL);
-
-	return t;
-}
-
-static int
-get_toolbar_pos (EphyToolbarsModel *model,
-		 const char *name)
-{
-	int i, n_toolbars;
-
-	n_toolbars = egg_toolbars_model_n_toolbars
-		(EGG_TOOLBARS_MODEL (model));
-
-	for (i = 0; i < n_toolbars; i++)
-	{
-		const char *t_name;
-
-		t_name = egg_toolbars_model_toolbar_nth
-			(EGG_TOOLBARS_MODEL (model), i);
-		if (strcmp (name, t_name) == 0)
-		{
-			return i;
-		}
-	}
-
-	return -1;
+	return EPHY_TOOLBARS_MODEL (g_object_new (EPHY_TYPE_TOOLBARS_MODEL,
+						  "bookmarks", bookmarks,
+						  NULL));
 }
 
 void
@@ -583,43 +621,3 @@ ephy_toolbars_model_has_bookmark (EphyToolbarsModel *model,
 
 	return found;
 }
-
-void
-ephy_toolbars_model_set_flag (EphyToolbarsModel *model,
-			      EggTbModelFlags flags)
-{
-	EggToolbarsModel *t = EGG_TOOLBARS_MODEL (model);
-	int i, n_toolbars;
-
-	n_toolbars = egg_toolbars_model_n_toolbars
-		(EGG_TOOLBARS_MODEL (model));
-
-	for (i = 0; i < n_toolbars; i++)
-	{
-		EggTbModelFlags old_flags;
-
-		old_flags = egg_toolbars_model_get_flags (t, i);
-
-		egg_toolbars_model_set_flags (t, old_flags | flags, i);
-	}
-}
-
-void
-ephy_toolbars_model_unset_flag (EphyToolbarsModel *model,
-			        EggTbModelFlags flags)
-{
-	EggToolbarsModel *t = EGG_TOOLBARS_MODEL (model);
-	int i, n_toolbars;
-
-	n_toolbars = egg_toolbars_model_n_toolbars
-		(EGG_TOOLBARS_MODEL (model));
-
-	for (i = 0; i < n_toolbars; i++)
-	{
-		EggTbModelFlags old_flags;
-
-		old_flags = egg_toolbars_model_get_flags (t, i);
-
-		egg_toolbars_model_set_flags (t, old_flags ^ flags, i);
-	}
-}
