@@ -15,15 +15,15 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.h,v 1.19 2003/12/07 10:23:31 chpe Exp $
+ *  $Id: ephy-window.h,v 1.26 2004/03/23 21:17:12 chpe Exp $
  */
 
 #ifndef EPHY_WINDOW_H
 #define EPHY_WINDOW_H
 
 #include "ephy-embed.h"
+#include "ephy-tab.h"
 #include "ephy-dialog.h"
-#include "ephy-notebook.h"
 
 #include <glib-object.h>
 #include <glib.h>
@@ -39,17 +39,15 @@ G_BEGIN_DECLS
 #define EPHY_WINDOW_GET_CLASS(o)(G_TYPE_INSTANCE_GET_CLASS ((o), EPHY_TYPE_WINDOW, EphyWindowClass))
 
 typedef struct EphyWindowClass EphyWindowClass;
-typedef struct EphyWindow EphyWindow;
+typedef struct _EphyWindow EphyWindow;
 typedef struct EphyWindowPrivate EphyWindowPrivate;
-typedef struct Toolbar Toolbar;
 
-struct EphyWindow
+struct _EphyWindow
 {
         GtkWindow parent;
 	/*< private >*/
         EphyWindowPrivate *priv;
 
-	/* Public to toolbar and statusbar, dont use outside */
 	/*< public >*/
 	GObject *ui_merge;
 };
@@ -59,27 +57,24 @@ struct EphyWindowClass
         GtkWindowClass parent_class;
 };
 
-typedef enum
-{
-	NormalMode,
-	FullscreenMode
-} EphyWindowMode;
-
 /* Include the header down here to resolve circular dependency */
-#include "ephy-tab.h"
+#include "ephy-notebook.h"
 
 GType		  ephy_window_get_type		  (void);
 
 EphyWindow	 *ephy_window_new		  (void);
 
-void		  ephy_window_request_chrome	  (EphyWindow *window,
-						   EmbedChromeMask chrome_flags);
+EphyWindow	 *ephy_window_new_with_chrome	  (EphyEmbedChrome chrome);
 
 void		  ephy_window_set_print_preview	  (EphyWindow *window,
 						   gboolean enabled);
 
+GtkWidget	 *ephy_window_get_toolbar	  (EphyWindow *window);
+
 GtkWidget	 *ephy_window_get_notebook	  (EphyWindow *window);
 
+GtkWidget	 *ephy_window_get_statusbar	  (EphyWindow *window);
+
 void		  ephy_window_add_tab		  (EphyWindow *window,
 						   EphyTab *tab,
 						   gint position,
@@ -105,8 +100,6 @@ EphyEmbed	 *ephy_window_get_active_embed	  (EphyWindow *window);
 
 GList		 *ephy_window_get_tabs		  (EphyWindow *window);
 
-Toolbar		 *ephy_window_get_toolbar	  (EphyWindow *window);
-
 void		  ephy_window_find		  (EphyWindow *window);
 
 void		  ephy_window_print		  (EphyWindow *window);
