@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: popup-commands.c,v 1.39 2004/02/24 19:59:00 xan Exp $
+ *  $Id: popup-commands.c,v 1.41 2004/05/13 20:56:00 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -87,46 +87,6 @@ popup_cmd_link_in_new_tab (GtkAction *action,
 			    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
 }
 
-void
-popup_cmd_image_in_new_tab (GtkAction *action,
-			    EphyWindow *window)
-{
-	EphyEmbedEvent *info;
-	EphyTab *tab;
-	const GValue *value;
-
-	tab = ephy_window_get_active_tab (window);
-
-	info = get_event_info (window);
-
-	ephy_embed_event_get_property (info, "image", &value);
-
-	ephy_shell_new_tab (ephy_shell, window, tab,
-			    g_value_get_string (value),
-			    EPHY_NEW_TAB_OPEN_PAGE |
-			    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
-}
-
-void
-popup_cmd_image_in_new_window (GtkAction *action,
-			       EphyWindow *window)
-{
-	EphyEmbedEvent *info;
-	EphyTab *tab;
-	const GValue *value;
-
-	tab = ephy_window_get_active_tab (window);
-
-	info = get_event_info (window);
-
-	ephy_embed_event_get_property (info, "image", &value);
-
-	ephy_shell_new_tab (ephy_shell, NULL, tab,
-			    g_value_get_string (value),
-			    EPHY_NEW_TAB_OPEN_PAGE |
-			    EPHY_NEW_TAB_IN_NEW_WINDOW);
-}
-
 void
 popup_cmd_bookmark_link (GtkAction *action,
 			 EphyWindow *window)
@@ -185,50 +145,6 @@ popup_cmd_bookmark_link (GtkAction *action,
 	}
 }
 
-void
-popup_cmd_frame_in_new_tab (GtkAction *action,
-			    EphyWindow *window)
-{
-	EphyTab *tab;
-	EphyEmbed *embed;
-	char *location;
-
-	tab = ephy_window_get_active_tab (window);
-
-	embed = ephy_window_get_active_embed (window);
-
-	location = ephy_embed_get_location (embed, FALSE);
-
-	ephy_shell_new_tab (ephy_shell, window, tab,
-			    location,
-			    EPHY_NEW_TAB_OPEN_PAGE |
-			    EPHY_NEW_TAB_IN_EXISTING_WINDOW);
-
-	g_free (location);
-}
-
-void
-popup_cmd_frame_in_new_window (GtkAction *action,
-			       EphyWindow *window)
-{
-	EphyTab *tab;
-	EphyEmbed *embed;
-	char *location;
-
-	tab = ephy_window_get_active_tab (window);
-
-	embed = ephy_window_get_active_embed (window);
-
-	location = ephy_embed_get_location (embed, FALSE);
-
-	ephy_shell_new_tab (ephy_shell, NULL, tab,
-			    location,
-			    EPHY_NEW_TAB_OPEN_PAGE |
-			    EPHY_NEW_TAB_IN_NEW_WINDOW);
-
-	g_free (location);
-}
-
 static void
 popup_cmd_copy_to_clipboard (EphyWindow *window, const char *text)
 {
