@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: prefs-dialog.c,v 1.72 2004/01/25 00:38:46 marco Exp $
+ *  $Id: prefs-dialog.c,v 1.80 2004/05/08 20:11:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -478,6 +478,7 @@ setup_font_combo (EphyDialog *dialog,
 	ephy_dialog_set_pref (dialog, properties[prop].id, NULL);
 
 	gtk_combo_box_set_model (GTK_COMBO_BOX (combo), sortmodel);
+	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), -1);
 
 	ephy_dialog_set_pref (dialog, properties[prop].id, key);
 
@@ -793,6 +794,8 @@ setup_add_language_dialog (PrefsDialog *pd)
 
 	dialog =  EPHY_DIALOG (g_object_new (EPHY_TYPE_DIALOG,
 					     "parent-window", window,
+					     "default-width", 260,
+					     "default-height", 230,
 					     NULL));
 
 	ephy_dialog_construct (dialog, 
@@ -1084,22 +1087,14 @@ create_language_section (EphyDialog *dialog)
 static char*
 get_download_button_label ()
 {
-	char *key, *label, *downloads_path;
+	char *key, *label, *downloads_path, *converted_dp;
 
 	key = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
+
 	downloads_path = ephy_file_downloads_dir ();
+	converted_dp = g_filename_to_utf8 (downloads_path, -1, NULL, NULL, NULL);
 
-	/* fallback to default downloads directory */
-	if (key == NULL)
-	{
-		key = ephy_file_downloads_dir ();
-	}
-
-	if (g_utf8_collate (key, "~/Desktop") == 0)
-	{
-		label = g_strdup (_("Desktop")); 
-	}
-	else if (g_utf8_collate (key, "~") == 0)
+	if (key == NULL || g_utf8_collate (key, "~") == 0)
 	{
 		/* Note that this does NOT refer to the home page but to a
 		 * user's home folder. It should be translated by the same
@@ -1107,17 +1102,22 @@ get_download_button_label ()
 		 * filechooser */
 		label = g_strdup (_("Home"));
 	}
-	else if (g_utf8_collate (key, downloads_path) == 0 ||
+	else if ((converted_dp != NULL && g_utf8_collate (key, converted_dp) == 0) ||
 		 g_utf8_collate (key, "Downloads") == 0)
 	{
 		label = g_strdup (_("Downloads"));
 	}
+	else if (g_utf8_collate (key, "~/Desktop") == 0)
+	{
+		label = g_strdup (_("Desktop")); 
+	}
 	else
 	{
 		label = g_strdup (key);
 	}
 
 	g_free (downloads_path);
+	g_free (converted_dp);
 	g_free (key);
 
 	return label;
@@ -1257,16 +1257,14 @@ void
 prefs_homepage_current_button_clicked_cb (GtkWidget *button,
 					  EphyDialog *dialog)
 {
-	EphySession *session;
-	EphyWindow *window;
+	GtkWidget *parent;
 	EphyEmbed *embed;
 	char *location;
 
-	session = EPHY_SESSION (ephy_shell_get_session (ephy_shell));
-	window = ephy_session_get_active_window (session);
-	g_return_if_fail (window != NULL);
+	parent = ephy_dialog_get_parent (dialog);
+	g_return_if_fail (parent != NULL);
 
-	embed = ephy_window_get_active_embed (window);
+	embed = ephy_window_get_active_embed (EPHY_WINDOW (parent));
 	g_return_if_fail (embed != NULL);
 
 	location = ephy_embed_get_location (embed, TRUE);
@@ -1283,7 +1281,7 @@ prefs_homepage_blank_button_clicked_cb (GtkWidget *button,
 static void
 download_path_response_cb (GtkDialog *fc, gint response, EphyDialog *dialog)
 {
-	if (response == EPHY_RESPONSE_OPEN)
+	if (response == GTK_RESPONSE_ACCEPT)
 	{
 		char *dir;
 
@@ -1294,7 +1292,7 @@ download_path_response_cb (GtkDialog *fc, gint response, EphyDialog *dialog)
 			char *label;
 
 			eel_gconf_set_path (CONF_STATE_DOWNLOAD_DIR, dir);
-			
+
 			button = ephy_dialog_get_control (dialog, properties[DOWNLOAD_PATH_BUTTON_PROP].id);
 			label = get_download_button_label ();
 			ephy_ellipsizing_label_set_text ((EphyEllipsizingLabel*) GTK_BIN (button)->child,
@@ -1322,10 +1320,9 @@ prefs_download_path_button_clicked_cb (GtkWidget *button,
 	
 		fc = ephy_file_chooser_new (_("Select a directory"),
 					    GTK_WIDGET (parent),
-					    GTK_FILE_CHOOSER_ACTION_OPEN,
-					    NULL);
-		gtk_file_chooser_set_folder_mode (GTK_FILE_CHOOSER (fc), TRUE);
-	
+					    GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER,
+					    NULL, EPHY_FILE_FILTER_NONE);
+
 		g_signal_connect (GTK_DIALOG (fc), "response",
 				    G_CALLBACK (download_path_response_cb),
 				    dialog);
